@@ -260,6 +260,40 @@ tablet_process_absolute(struct tablet_dispatch *tablet,
 	}
 }
 
+static inline int
+axis_range_percentage(const struct input_absinfo *a, double percent)
+{
+	return (a->maximum - a->minimum) * percent/100.0 + a->minimum;
+}
+
+static void
+tablet_change_area(struct evdev_device *device)
+{
+	struct tablet_dispatch *tablet = tablet_dispatch(device->dispatch);
+
+	if (memcmp(&tablet->area.rect, &tablet->area.want_rect, sizeof(tablet->area.rect)) == 0)
+		return;
+
+	if (!tablet_has_status(tablet, TABLET_TOOL_OUT_OF_PROXIMITY))
+		return;
+
+	tablet->area.rect = tablet->area.want_rect;
+
+	evdev_log_debug(device,
+			"tablet-area: area is %.2f/%.2f - %.2f/%.2f\n",
+			tablet->area.rect.x1,
+			tablet->area.rect.y1,
+			tablet->area.rect.x2,
+			tablet->area.rect.y2);
+
+	const struct input_absinfo *absx = device->abs.absinfo_x;
+	const struct input_absinfo *absy = device->abs.absinfo_y;
+	tablet->area.x.minimum = axis_range_percentage(absx, tablet->area.rect.x1 * 100);
+	tablet->area.x.maximum = axis_range_percentage(absx, tablet->area.rect.x2 * 100);
+	tablet->area.y.minimum = axis_range_percentage(absy, tablet->area.rect.y1 * 100);
+	tablet->area.y.maximum = axis_range_percentage(absy, tablet->area.rect.y2 * 100);
+}
+
 static void
 tablet_apply_rotation(struct evdev_device *device)
 {
@@ -442,6 +476,52 @@ normalize_wheel(struct tablet_dispatch *tablet,
 	return value * device->scroll.wheel_click_angle.x;
 }
 
+static bool
+is_inside_area(struct tablet_dispatch *tablet,
+	       const struct device_coords *point,
+	       double normalized_margin)
+{
+	if (tablet->area.rect.x1 == 0.0 && tablet->area.rect.x2 == 1.0 &&
+	    tablet->area.rect.y1 == 0.0 && tablet->area.rect.y2 == 1.0)
+		return true;
+
+	assert(normalized_margin > 0.0);
+	assert(normalized_margin <= 1.0);
+
+	int xmargin = (tablet->area.x.maximum - tablet->area.x.minimum) * normalized_margin;
+	int ymargin = (tablet->area.y.maximum - tablet->area.y.minimum) * normalized_margin;
+
+	return (point->x >= tablet->area.x.minimum - xmargin &&
+	        point->x <= tablet->area.x.maximum + xmargin &&
+	        point->y >= tablet->area.y.minimum - ymargin &&
+	        point->y <= tablet->area.y.maximum + ymargin);
+}
+
+static void
+apply_tablet_area(struct tablet_dispatch *tablet,
+		  struct evdev_device *device,
+		  struct device_coords *point)
+{
+	if (tablet->area.rect.x1 == 0.0 && tablet->area.rect.x2 == 1.0 &&
+	    tablet->area.rect.y1 == 0.0 && tablet->area.rect.y2 == 1.0)
+		return;
+
+	/* The point is somewhere on the tablet in device coordinates,
+	 * but we need it relative to the x/y offset.
+	 * So clip it first, then offset it to our area min/max.
+	 *
+	 * Right now we're just clipping, we don't completely
+	 * ignore events. What we should do is ignore events outside
+	 * altogether and generate prox in/out events when we actually
+	 * enter the area.
+	 */
+	point->x = min(point->x, tablet->area.x.maximum);
+	point->y = min(point->y, tablet->area.y.maximum);
+
+	point->x = max(point->x, tablet->area.x.minimum);
+	point->y = max(point->y, tablet->area.y.minimum);
+}
+
 static inline void
 tablet_update_xy(struct tablet_dispatch *tablet,
 		 struct evdev_device *device)
@@ -455,7 +535,7 @@ tablet_update_xy(struct tablet_dispatch *tablet,
 
 	if (bit_is_set(tablet->changed_axes, LIBINPUT_TABLET_TOOL_AXIS_X) ||
 	    bit_is_set(tablet->changed_axes, LIBINPUT_TABLET_TOOL_AXIS_Y)) {
-		absinfo = libevdev_get_abs_info(device->evdev, ABS_X);
+		absinfo = device->abs.absinfo_x;
 
 		if (tablet->rotation.rotate)
 			value = invert_axis(absinfo);
@@ -464,7 +544,7 @@ tablet_update_xy(struct tablet_dispatch *tablet,
 
 		tablet->axes.point.x = value;
 
-		absinfo = libevdev_get_abs_info(device->evdev, ABS_Y);
+		absinfo = device->abs.absinfo_y;
 
 		if (tablet->rotation.rotate)
 			value = invert_axis(absinfo);
@@ -473,7 +553,10 @@ tablet_update_xy(struct tablet_dispatch *tablet,
 
 		tablet->axes.point.y = value;
 
+		/* calibration and area are currently mutually exclusive so
+		 * one of those is a noop */
 		evdev_transform_absolute(device, &tablet->axes.point);
+		apply_tablet_area(tablet, device, &tablet->axes.point);
 	}
 }
 
@@ -929,12 +1012,12 @@ copy_button_cap(const struct tablet_dispatch *tablet,
 		set_bit(tool->buttons, button);
 }
 
-#if HAVE_LIBWACOM
-static inline int
+static inline bool
 tool_set_bits_from_libwacom(const struct tablet_dispatch *tablet,
 			    struct libinput_tablet_tool *tool)
 {
-	int rc = 1;
+	bool rc = false;
+#if HAVE_LIBWACOM
 	WacomDeviceDatabase *db;
 	const WacomStylus *s = NULL;
 	int code;
@@ -992,11 +1075,10 @@ tool_set_bits_from_libwacom(const struct tablet_dispatch *tablet,
 	if (axes & WACOM_AXIS_TYPE_PRESSURE)
 		copy_axis_cap(tablet, tool, LIBINPUT_TABLET_TOOL_AXIS_PRESSURE);
 
-	rc = 0;
-
+	rc = true;
+#endif
 	return rc;
 }
-#endif
 
 static void
 tool_set_bits(const struct tablet_dispatch *tablet,
@@ -1007,10 +1089,9 @@ tool_set_bits(const struct tablet_dispatch *tablet,
 	copy_axis_cap(tablet, tool, LIBINPUT_TABLET_TOOL_AXIS_X);
 	copy_axis_cap(tablet, tool, LIBINPUT_TABLET_TOOL_AXIS_Y);
 
-#if HAVE_LIBWACOM
-	if (tool_set_bits_from_libwacom(tablet, tool) == 0)
+	if (tool_set_bits_from_libwacom(tablet, tool))
 		return;
-#endif
+
 	/* If we don't have libwacom, we simply copy any axis we have on the
 	   tablet onto the tool. Except we know that mice only have rotation
 	   anyway.
@@ -1072,12 +1153,6 @@ tool_set_bits(const struct tablet_dispatch *tablet,
 	}
 }
 
-static inline int
-axis_range_percentage(const struct input_absinfo *a, double percent)
-{
-	return (a->maximum - a->minimum) * percent/100.0 + a->minimum;
-}
-
 static bool
 tablet_get_quirked_pressure_thresholds(struct tablet_dispatch *tablet,
 				       int *hi,
@@ -1340,7 +1415,9 @@ tablet_notify_button_mask(struct tablet_dispatch *tablet,
 				     tip_state,
 				     &tablet->axes,
 				     i,
-				     state);
+				     state,
+				     &tablet->area.x,
+				     &tablet->area.y);
 	}
 }
 
@@ -1739,7 +1816,9 @@ tablet_send_proximity_in(struct tablet_dispatch *tablet,
 				tool,
 				LIBINPUT_TABLET_TOOL_PROXIMITY_STATE_IN,
 				tablet->changed_axes,
-				axes);
+				axes,
+				&tablet->area.x,
+				&tablet->area.y);
 	tablet_unset_status(tablet, TABLET_TOOL_ENTERING_PROXIMITY);
 	tablet_unset_status(tablet, TABLET_AXES_UPDATED);
 
@@ -1760,15 +1839,20 @@ tablet_send_proximity_out(struct tablet_dispatch *tablet,
 	if (!tablet_has_status(tablet, TABLET_TOOL_LEAVING_PROXIMITY))
 		return false;
 
-	tablet_notify_proximity(&device->base,
-				time,
-				tool,
-				LIBINPUT_TABLET_TOOL_PROXIMITY_STATE_OUT,
-				tablet->changed_axes,
-				axes);
+	if (!tablet_has_status(tablet, TABLET_TOOL_OUTSIDE_AREA)) {
+		tablet_notify_proximity(&device->base,
+					time,
+					tool,
+					LIBINPUT_TABLET_TOOL_PROXIMITY_STATE_OUT,
+					tablet->changed_axes,
+					axes,
+					&tablet->area.x,
+					&tablet->area.y);
+	}
 
 	tablet_set_status(tablet, TABLET_TOOL_OUT_OF_PROXIMITY);
 	tablet_unset_status(tablet, TABLET_TOOL_LEAVING_PROXIMITY);
+	tablet_unset_status(tablet, TABLET_TOOL_OUTSIDE_AREA);
 
 	tablet_reset_changed_axes(tablet);
 	axes->delta.x = 0;
@@ -1790,7 +1874,9 @@ tablet_send_tip(struct tablet_dispatch *tablet,
 				  tool,
 				  LIBINPUT_TABLET_TOOL_TIP_DOWN,
 				  tablet->changed_axes,
-				  axes);
+				  axes,
+				  &tablet->area.x,
+				  &tablet->area.y);
 		tablet_unset_status(tablet, TABLET_AXES_UPDATED);
 		tablet_unset_status(tablet, TABLET_TOOL_ENTERING_CONTACT);
 		tablet_set_status(tablet, TABLET_TOOL_IN_CONTACT);
@@ -1808,7 +1894,9 @@ tablet_send_tip(struct tablet_dispatch *tablet,
 				  tool,
 				  LIBINPUT_TABLET_TOOL_TIP_UP,
 				  tablet->changed_axes,
-				  axes);
+				  axes,
+				  &tablet->area.x,
+				  &tablet->area.y);
 		tablet_unset_status(tablet, TABLET_AXES_UPDATED);
 		tablet_unset_status(tablet, TABLET_TOOL_LEAVING_CONTACT);
 		tablet_unset_status(tablet, TABLET_TOOL_IN_CONTACT);
@@ -1846,7 +1934,9 @@ tablet_send_axes(struct tablet_dispatch *tablet,
 			   tool,
 			   tip_state,
 			   tablet->changed_axes,
-			   axes);
+			   axes,
+			   &tablet->area.x,
+			   &tablet->area.y);
 	tablet_unset_status(tablet, TABLET_AXES_UPDATED);
 	tablet_reset_changed_axes(tablet);
 	axes->delta.x = 0;
@@ -1916,6 +2006,7 @@ tablet_send_events(struct tablet_dispatch *tablet,
 	if (tablet_send_proximity_out(tablet, tool, device, &axes, time)) {
 		tablet_change_to_left_handed(device);
 		tablet_apply_rotation(device);
+		tablet_change_area(device);
 		tablet_history_reset(tablet);
 	}
 }
@@ -2105,19 +2196,45 @@ reprocess:
 		if (tablet_has_status(tablet, TABLET_TOOL_IN_CONTACT))
 			tablet_set_status(tablet, TABLET_TOOL_LEAVING_CONTACT);
 		apply_pressure_range_configuration(tablet, tool);
-	} else if (tablet_has_status(tablet, TABLET_TOOL_ENTERING_PROXIMITY)) {
-		tablet_mark_all_axes_changed(tablet, tool);
-		update_pressure_offset(tablet, device, tool);
-		detect_pressure_offset(tablet, device, tool);
-		detect_tool_contact(tablet, device, tool);
-		sanitize_tablet_axes(tablet, tool);
-	} else if (tablet_has_status(tablet, TABLET_AXES_UPDATED)) {
-		update_pressure_offset(tablet, device, tool);
-		detect_tool_contact(tablet, device, tool);
-		sanitize_tablet_axes(tablet, tool);
+	} else if (!tablet_has_status(tablet, TABLET_TOOL_OUTSIDE_AREA)) {
+		if (tablet_has_status(tablet, TABLET_TOOL_ENTERING_PROXIMITY)) {
+			/* If we get into proximity outside the tablet area, we ignore
+			 * that whole sequence of events even if we later move into
+			 * the allowed area. This may be bad UX but it's complicated to
+			 * implement so let's wait for someone to actually complain
+			 * about it.
+			 *
+			 * We allow a margin of 3% (6mm on a 200mm tablet) to be "within"
+			 * the area - there we clip to the area but do not ignore the
+			 * sequence.
+			 */
+			const struct device_coords point = {
+				device->abs.absinfo_x->value,
+				device->abs.absinfo_y->value,
+			};
+
+			const double margin = 0.03;
+			if (is_inside_area(tablet, &point, margin)) {
+				tablet_mark_all_axes_changed(tablet, tool);
+				update_pressure_offset(tablet, device, tool);
+				detect_pressure_offset(tablet, device, tool);
+				detect_tool_contact(tablet, device, tool);
+				sanitize_tablet_axes(tablet, tool);
+			} else {
+				tablet_set_status(tablet, TABLET_TOOL_OUTSIDE_AREA);
+				tablet_unset_status(tablet, TABLET_TOOL_ENTERING_PROXIMITY);
+			}
+		} else if (tablet_has_status(tablet, TABLET_AXES_UPDATED)) {
+			update_pressure_offset(tablet, device, tool);
+			detect_tool_contact(tablet, device, tool);
+			sanitize_tablet_axes(tablet, tool);
+		}
+
 	}
 
-	tablet_send_events(tablet, tool, device, time);
+	if (!tablet_has_status(tablet, TABLET_TOOL_OUTSIDE_AREA)) {
+		tablet_send_events(tablet, tool, device, time);
+	}
 
 	if (process_tool_twice)
 		goto reprocess;
@@ -2503,6 +2620,71 @@ tablet_init_calibration(struct tablet_dispatch *tablet,
 		evdev_init_calibration(device, &tablet->calibration);
 }
 
+static int
+tablet_area_has_rectangle(struct libinput_device *device)
+{
+	return 1;
+}
+
+static enum libinput_config_status
+tablet_area_set_rectangle(struct libinput_device *device,
+			  const struct libinput_config_area_rectangle *rectangle)
+{
+	struct evdev_device *evdev = evdev_device(device);
+	struct tablet_dispatch *tablet = tablet_dispatch(evdev->dispatch);
+
+	if (rectangle->x1 >= rectangle->x2 || rectangle->y1 >= rectangle->y2)
+		return LIBINPUT_CONFIG_STATUS_INVALID;
+
+	if (rectangle->x1 < 0.0 || rectangle->x2 > 1.0 ||
+	    rectangle->y1 < 0.0 || rectangle->y2 > 1.0)
+		return LIBINPUT_CONFIG_STATUS_INVALID;
+
+	tablet->area.want_rect = *rectangle;
+
+	tablet_change_area(evdev);
+
+	return LIBINPUT_CONFIG_STATUS_SUCCESS;
+}
+
+static struct libinput_config_area_rectangle
+tablet_area_get_rectangle(struct libinput_device *device)
+{
+	struct evdev_device *evdev = evdev_device(device);
+	struct tablet_dispatch *tablet = tablet_dispatch(evdev->dispatch);
+
+	return tablet->area.rect;
+}
+
+static struct libinput_config_area_rectangle
+tablet_area_get_default_rectangle(struct libinput_device *device)
+{
+	struct libinput_config_area_rectangle rect = {
+		0.0, 0.0, 1.0, 1.0,
+	};
+	return rect;
+}
+
+static void
+tablet_init_area(struct tablet_dispatch *tablet,
+		 struct evdev_device *device)
+{
+	tablet->area.rect = (struct libinput_config_area_rectangle) {
+		0.0, 0.0, 1.0, 1.0,
+	};
+	tablet->area.want_rect = tablet->area.rect;
+	tablet->area.x = *device->abs.absinfo_x;
+	tablet->area.y = *device->abs.absinfo_y;
+
+	if (!libevdev_has_property(device->evdev, INPUT_PROP_DIRECT)) {
+		device->base.config.area = &tablet->area.config;
+		tablet->area.config.has_rectangle = tablet_area_has_rectangle;
+		tablet->area.config.set_rectangle = tablet_area_set_rectangle;
+		tablet->area.config.get_rectangle = tablet_area_get_rectangle;
+		tablet->area.config.get_default_rectangle = tablet_area_get_default_rectangle;
+	}
+}
+
 static void
 tablet_init_proximity_threshold(struct tablet_dispatch *tablet,
 				struct evdev_device *device)
@@ -2579,58 +2761,53 @@ tablet_init_accel(struct tablet_dispatch *tablet, struct evdev_device *device)
 }
 
 static void
-tablet_init_left_handed(struct evdev_device *device)
+tablet_init_left_handed(struct evdev_device *device,
+			WacomDevice *wacom)
 {
-	if (evdev_tablet_has_left_handed(device))
+	bool has_left_handed = true;
+
+#if HAVE_LIBWACOM
+	has_left_handed = !wacom || libwacom_is_reversible(wacom);
+#endif
+	if (has_left_handed)
 		evdev_init_left_handed(device,
 				       tablet_change_to_left_handed);
 }
 
-static void
-tablet_lookup_libwacom(struct evdev_device *device,
-		       struct tablet_dispatch *tablet,
-		       bool *is_aes,
-		       bool *is_display_tablet)
+static inline bool
+tablet_is_display_tablet(WacomDevice *wacom)
+{
+#if HAVE_LIBWACOM
+	return !wacom ||
+		(libwacom_get_integration_flags(wacom) & (WACOM_DEVICE_INTEGRATED_SYSTEM|WACOM_DEVICE_INTEGRATED_DISPLAY));
+#else
+	return true;
+#endif
+}
+
+static inline bool
+tablet_is_aes(struct evdev_device *device, WacomDevice *wacom)
 {
 #if HAVE_LIBWACOM
-	const char *devnode;
-	WacomDeviceDatabase *db;
-	WacomDevice *libwacom_device = NULL;
-	const int *stylus_ids;
-	int nstyli;
 	int vid = evdev_device_get_id_vendor(device);
-
-	db = tablet_libinput_context(tablet)->libwacom.db;
-	if (!db)
-		return;
-
-	devnode = udev_device_get_devnode(device->udev_device);
-	libwacom_device = libwacom_new_from_path(db, devnode, WFALLBACK_NONE, NULL);
-	if (!libwacom_device)
-		return;
-
-	*is_display_tablet = !!(libwacom_get_integration_flags(libwacom_device)
-		& (WACOM_DEVICE_INTEGRATED_SYSTEM|WACOM_DEVICE_INTEGRATED_DISPLAY));
-
 	/* Wacom-specific check for whether smoothing is required:
 	 * libwacom keeps all the AES pens in a single group, so any device
 	 * that supports AES pens will list all AES pens. 0x11 is one of the
 	 * lenovo pens so we use that as the flag of whether the tablet
 	 * is an AES tablet
 	 */
-	if (vid != VENDOR_ID_WACOM)
-		return;
-
-	stylus_ids = libwacom_get_supported_styli(libwacom_device, &nstyli);
-	for (int i = 0; i < nstyli; i++) {
-		if (stylus_ids[i] == 0x11) {
-			*is_aes = true;
-			break;
+	if (wacom && vid == VENDOR_ID_WACOM) {
+		int nstyli;
+		const int *stylus_ids = libwacom_get_supported_styli(wacom, &nstyli);
+		for (int i = 0; i < nstyli; i++) {
+			if (stylus_ids[i] == 0x11) {
+				return true;
+			}
 		}
 	}
-
-	libwacom_destroy(libwacom_device);
 #endif
+
+	return false;
 }
 
 static void
@@ -2741,9 +2918,35 @@ static int
 tablet_init(struct tablet_dispatch *tablet,
 	    struct evdev_device *device)
 {
+	struct libinput *li = evdev_libinput_context(device);
 	struct libevdev *evdev = device->evdev;
 	enum libinput_tablet_tool_axis axis;
-	int rc;
+	int rc = -1;
+	WacomDevice *wacom = NULL;
+#if HAVE_LIBWACOM
+	WacomDeviceDatabase *db = libinput_libwacom_ref(li);
+	if (db) {
+		char event_path[64];
+		snprintf(event_path,
+			 sizeof(event_path),
+			 "/dev/input/%s",
+			 evdev_device_get_sysname(device));
+		wacom = libwacom_new_from_path(db, event_path, WFALLBACK_NONE, NULL);
+		if (!wacom) {
+			wacom = libwacom_new_from_usbid(db,
+							evdev_device_get_id_vendor(device),
+							evdev_device_get_id_product(device),
+							NULL);
+		}
+		if (!wacom) {
+			evdev_log_info(device,
+				       "device \"%s\" (%04x:%04x) is not known to libwacom\n",
+				       evdev_device_get_name(device),
+				       evdev_device_get_id_vendor(device),
+				       evdev_device_get_id_product(device));
+		}
+	}
+#endif
 
 	tablet->base.dispatch_type = DISPATCH_TABLET;
 	tablet->base.interface = &tablet_interface;
@@ -2753,11 +2956,10 @@ tablet_init(struct tablet_dispatch *tablet,
 	list_init(&tablet->tool_list);
 
 	if (tablet_reject_device(device))
-		return -1;
+		goto out;
 
-	bool is_aes = false;
-	bool is_display_tablet = false;
-	tablet_lookup_libwacom(device, tablet, &is_aes, &is_display_tablet);
+	bool is_aes = tablet_is_aes(device, wacom);
+	bool is_display_tablet = tablet_is_display_tablet(wacom);
 
 	if (!libevdev_has_event_code(evdev, EV_KEY, BTN_TOOL_PEN)) {
 		libevdev_enable_event_code(evdev, EV_KEY, BTN_TOOL_PEN, NULL);
@@ -2773,13 +2975,14 @@ tablet_init(struct tablet_dispatch *tablet,
 
 	tablet_fix_tilt(tablet, device);
 	tablet_init_calibration(tablet, device, is_display_tablet);
+	tablet_init_area(tablet, device);
 	tablet_init_proximity_threshold(tablet, device);
 	rc = tablet_init_accel(tablet, device);
 	if (rc != 0)
-		return rc;
+		goto out;
 
 	evdev_init_sendevents(device, &tablet->base);
-	tablet_init_left_handed(device);
+	tablet_init_left_handed(device, wacom);
 	tablet_init_smoothing(device, tablet, is_aes);
 
 	for (axis = LIBINPUT_TABLET_TOOL_AXIS_X;
@@ -2796,12 +2999,20 @@ tablet_init(struct tablet_dispatch *tablet,
 	tablet->quirks.need_to_force_prox_out = true;
 
 	libinput_timer_init(&tablet->quirks.prox_out_timer,
-			    tablet_libinput_context(tablet),
+			    li,
 			    "proxout",
 			    tablet_proximity_out_quirk_timer_func,
 			    tablet);
 
-	return 0;
+	rc = 0;
+out:
+#if HAVE_LIBWACOM
+	if (wacom)
+		libwacom_destroy(wacom);
+	if (db)
+		libinput_libwacom_unref(li);
+#endif
+	return rc;
 }
 
 struct evdev_dispatch *
