@@ -23,7 +23,6 @@
 
 #include <config.h>
 
-#include <check.h>
 #include <libinput.h>
 #include <valgrind/valgrind.h>
 
@@ -70,14 +69,14 @@ test_gesture_swipe_3fg(int cardinal, enum hold_gesture_behaviour hold)
 	litest_touch_down(dev, 0, 40, 40);
 	litest_touch_down(dev, 1, 50, 40);
 	litest_touch_down(dev, 2, 60, 40);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	if (hold == HOLD_GESTURE_REQUIRE)
 		litest_timeout_gesture_hold();
 
 	litest_touch_move_three_touches(dev, 40, 40, 50, 40, 60, 40, dir_x,
 					dir_y, 10);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	if (hold == HOLD_GESTURE_REQUIRE) {
 		litest_assert_gesture_event(li,
@@ -94,8 +93,8 @@ test_gesture_swipe_3fg(int cardinal, enum hold_gesture_behaviour hold)
 					 3);
 	dx = libinput_event_gesture_get_dx(gevent);
 	dy = libinput_event_gesture_get_dy(gevent);
-	ck_assert(dx == 0.0);
-	ck_assert(dy == 0.0);
+	litest_assert(dx == 0.0);
+	litest_assert(dy == 0.0);
 	libinput_event_destroy(event);
 
 	while ((event = libinput_get_event(li)) != NULL) {
@@ -106,34 +105,34 @@ test_gesture_swipe_3fg(int cardinal, enum hold_gesture_behaviour hold)
 		dx = libinput_event_gesture_get_dx(gevent);
 		dy = libinput_event_gesture_get_dy(gevent);
 		if (dir_x == 0.0)
-			ck_assert(dx == 0.0);
+			litest_assert(dx == 0.0);
 		else if (dir_x < 0.0)
-			ck_assert(dx < 0.0);
+			litest_assert(dx < 0.0);
 		else if (dir_x > 0.0)
-			ck_assert(dx > 0.0);
+			litest_assert(dx > 0.0);
 
 		if (dir_y == 0.0)
-			ck_assert(dy == 0.0);
+			litest_assert(dy == 0.0);
 		else if (dir_y < 0.0)
-			ck_assert(dy < 0.0);
+			litest_assert(dy < 0.0);
 		else if (dir_y > 0.0)
-			ck_assert(dy > 0.0);
+			litest_assert(dy > 0.0);
 
 		dx = libinput_event_gesture_get_dx_unaccelerated(gevent);
 		dy = libinput_event_gesture_get_dy_unaccelerated(gevent);
 		if (dir_x == 0.0)
-			ck_assert(dx == 0.0);
+			litest_assert(dx == 0.0);
 		else if (dir_x < 0.0)
-			ck_assert(dx < 0.0);
+			litest_assert(dx < 0.0);
 		else if (dir_x > 0.0)
-			ck_assert(dx > 0.0);
+			litest_assert(dx > 0.0);
 
 		if (dir_y == 0.0)
-			ck_assert(dy == 0.0);
+			litest_assert(dy == 0.0);
 		else if (dir_y < 0.0)
-			ck_assert(dy < 0.0);
+			litest_assert(dy < 0.0);
 		else if (dir_y > 0.0)
-			ck_assert(dy > 0.0);
+			litest_assert(dy > 0.0);
 
 		libinput_event_destroy(event);
 	}
@@ -141,12 +140,12 @@ test_gesture_swipe_3fg(int cardinal, enum hold_gesture_behaviour hold)
 	litest_touch_up(dev, 0);
 	litest_touch_up(dev, 1);
 	litest_touch_up(dev, 2);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
 					 LIBINPUT_EVENT_GESTURE_SWIPE_END,
 					 3);
-	ck_assert(!libinput_event_gesture_get_cancelled(gevent));
+	litest_assert(!libinput_event_gesture_get_cancelled(gevent));
 	libinput_event_destroy(event);
 }
 
@@ -183,7 +182,7 @@ test_gesture_swipe_4fg(int cardinal, enum hold_gesture_behaviour hold)
 	litest_touch_down(dev, 1, 50, 40);
 	litest_touch_down(dev, 2, 60, 40);
 	litest_touch_down(dev, 3, 70, 40);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	if (hold == HOLD_GESTURE_REQUIRE)
 		litest_timeout_gesture_hold();
@@ -211,10 +210,10 @@ test_gesture_swipe_4fg(int cardinal, enum hold_gesture_behaviour hold)
 				  70 + dir_x,
 				  40 + dir_y);
 		litest_pop_event_frame(dev);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	if (hold == HOLD_GESTURE_REQUIRE) {
 		litest_assert_gesture_event(li,
@@ -231,8 +230,8 @@ test_gesture_swipe_4fg(int cardinal, enum hold_gesture_behaviour hold)
 					 4);
 	dx = libinput_event_gesture_get_dx(gevent);
 	dy = libinput_event_gesture_get_dy(gevent);
-	ck_assert(dx == 0.0);
-	ck_assert(dy == 0.0);
+	litest_assert(dx == 0.0);
+	litest_assert(dy == 0.0);
 	libinput_event_destroy(event);
 
 	while ((event = libinput_get_event(li)) != NULL) {
@@ -243,34 +242,34 @@ test_gesture_swipe_4fg(int cardinal, enum hold_gesture_behaviour hold)
 		dx = libinput_event_gesture_get_dx(gevent);
 		dy = libinput_event_gesture_get_dy(gevent);
 		if (dir_x == 0.0)
-			ck_assert(dx == 0.0);
+			litest_assert(dx == 0.0);
 		else if (dir_x < 0.0)
-			ck_assert(dx < 0.0);
+			litest_assert(dx < 0.0);
 		else if (dir_x > 0.0)
-			ck_assert(dx > 0.0);
+			litest_assert(dx > 0.0);
 
 		if (dir_y == 0.0)
-			ck_assert(dy == 0.0);
+			litest_assert(dy == 0.0);
 		else if (dir_y < 0.0)
-			ck_assert(dy < 0.0);
+			litest_assert(dy < 0.0);
 		else if (dir_y > 0.0)
-			ck_assert(dy > 0.0);
+			litest_assert(dy > 0.0);
 
 		dx = libinput_event_gesture_get_dx_unaccelerated(gevent);
 		dy = libinput_event_gesture_get_dy_unaccelerated(gevent);
 		if (dir_x == 0.0)
-			ck_assert(dx == 0.0);
+			litest_assert(dx == 0.0);
 		else if (dir_x < 0.0)
-			ck_assert(dx < 0.0);
+			litest_assert(dx < 0.0);
 		else if (dir_x > 0.0)
-			ck_assert(dx > 0.0);
+			litest_assert(dx > 0.0);
 
 		if (dir_y == 0.0)
-			ck_assert(dy == 0.0);
+			litest_assert(dy == 0.0);
 		else if (dir_y < 0.0)
-			ck_assert(dy < 0.0);
+			litest_assert(dy < 0.0);
 		else if (dir_y > 0.0)
-			ck_assert(dy > 0.0);
+			litest_assert(dy > 0.0);
 
 		libinput_event_destroy(event);
 	}
@@ -279,12 +278,12 @@ test_gesture_swipe_4fg(int cardinal, enum hold_gesture_behaviour hold)
 	litest_touch_up(dev, 1);
 	litest_touch_up(dev, 2);
 	litest_touch_up(dev, 3);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
 					 LIBINPUT_EVENT_GESTURE_SWIPE_END,
 					 4);
-	ck_assert(!libinput_event_gesture_get_cancelled(gevent));
+	litest_assert(!libinput_event_gesture_get_cancelled(gevent));
 	libinput_event_destroy(event);
 }
 
@@ -334,7 +333,7 @@ test_gesture_pinch_2fg(int cardinal, enum hold_gesture_behaviour hold)
 
 	litest_touch_down(dev, 0, 50 + dir_x, 50 + dir_y);
 	litest_touch_down(dev, 1, 50 - dir_x, 50 - dir_y);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	if (hold == HOLD_GESTURE_REQUIRE)
 		litest_timeout_gesture_hold();
@@ -358,7 +357,7 @@ test_gesture_pinch_2fg(int cardinal, enum hold_gesture_behaviour hold)
 				  50 - dir_x,
 				  50 - dir_y);
 		litest_pop_event_frame(dev);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
 	if (hold == HOLD_GESTURE_REQUIRE) {
@@ -377,9 +376,9 @@ test_gesture_pinch_2fg(int cardinal, enum hold_gesture_behaviour hold)
 	dx = libinput_event_gesture_get_dx(gevent);
 	dy = libinput_event_gesture_get_dy(gevent);
 	scale = libinput_event_gesture_get_scale(gevent);
-	ck_assert(dx == 0.0);
-	ck_assert(dy == 0.0);
-	ck_assert(scale == 1.0);
+	litest_assert(dx == 0.0);
+	litest_assert(dy == 0.0);
+	litest_assert(scale == 1.0);
 
 	libinput_event_destroy(event);
 
@@ -391,23 +390,23 @@ test_gesture_pinch_2fg(int cardinal, enum hold_gesture_behaviour hold)
 		oldscale = scale;
 		scale = libinput_event_gesture_get_scale(gevent);
 
-		ck_assert(scale < oldscale);
+		litest_assert(scale < oldscale);
 
 		angle = libinput_event_gesture_get_angle_delta(gevent);
-		ck_assert_double_le(fabs(angle), 1.0);
+		litest_assert_double_le(fabs(angle), 1.0);
 
 		libinput_event_destroy(event);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
 	litest_touch_up(dev, 0);
 	litest_touch_up(dev, 1);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
 					 LIBINPUT_EVENT_GESTURE_PINCH_END,
 					 2);
-	ck_assert(!libinput_event_gesture_get_cancelled(gevent));
+	litest_assert(!libinput_event_gesture_get_cancelled(gevent));
 	libinput_event_destroy(event);
 }
 
@@ -445,7 +444,7 @@ test_gesture_pinch_3fg(int cardinal, enum hold_gesture_behaviour hold)
 	litest_touch_down(dev, 0, 50 + dir_x, 50 + dir_y);
 	litest_touch_down(dev, 1, 50 - dir_x, 50 - dir_y);
 	litest_touch_down(dev, 2, 51 - dir_x, 51 - dir_y);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	if (hold == HOLD_GESTURE_REQUIRE)
 		litest_timeout_gesture_hold();
@@ -473,7 +472,7 @@ test_gesture_pinch_3fg(int cardinal, enum hold_gesture_behaviour hold)
 				  51 - dir_x,
 				  51 - dir_y);
 		litest_pop_event_frame(dev);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
 	if (hold == HOLD_GESTURE_REQUIRE) {
@@ -491,9 +490,9 @@ test_gesture_pinch_3fg(int cardinal, enum hold_gesture_behaviour hold)
 	dx = libinput_event_gesture_get_dx(gevent);
 	dy = libinput_event_gesture_get_dy(gevent);
 	scale = libinput_event_gesture_get_scale(gevent);
-	ck_assert(dx == 0.0);
-	ck_assert(dy == 0.0);
-	ck_assert(scale == 1.0);
+	litest_assert(dx == 0.0);
+	litest_assert(dy == 0.0);
+	litest_assert(scale == 1.0);
 
 	libinput_event_destroy(event);
 
@@ -505,24 +504,24 @@ test_gesture_pinch_3fg(int cardinal, enum hold_gesture_behaviour hold)
 		oldscale = scale;
 		scale = libinput_event_gesture_get_scale(gevent);
 
-		ck_assert(scale < oldscale);
+		litest_assert(scale < oldscale);
 
 		angle = libinput_event_gesture_get_angle_delta(gevent);
-		ck_assert_double_le(fabs(angle), 1.0);
+		litest_assert_double_le(fabs(angle), 1.0);
 
 		libinput_event_destroy(event);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
 	litest_touch_up(dev, 0);
 	litest_touch_up(dev, 1);
 	litest_touch_up(dev, 2);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
 					 LIBINPUT_EVENT_GESTURE_PINCH_END,
 					 3);
-	ck_assert(!libinput_event_gesture_get_cancelled(gevent));
+	litest_assert(!libinput_event_gesture_get_cancelled(gevent));
 	libinput_event_destroy(event);
 }
 
@@ -561,7 +560,7 @@ test_gesture_pinch_4fg(int cardinal, enum hold_gesture_behaviour hold)
 	litest_touch_down(dev, 1, 50 - dir_x, 50 - dir_y);
 	litest_touch_down(dev, 2, 51 - dir_x, 51 - dir_y);
 	litest_touch_down(dev, 3, 52 - dir_x, 52 - dir_y);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	if (hold == HOLD_GESTURE_REQUIRE)
 		litest_timeout_gesture_hold();
@@ -593,7 +592,7 @@ test_gesture_pinch_4fg(int cardinal, enum hold_gesture_behaviour hold)
 				  52 - dir_x,
 				  52 - dir_y);
 		litest_pop_event_frame(dev);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
 	if (hold == HOLD_GESTURE_REQUIRE) {
@@ -612,9 +611,9 @@ test_gesture_pinch_4fg(int cardinal, enum hold_gesture_behaviour hold)
 	dx = libinput_event_gesture_get_dx(gevent);
 	dy = libinput_event_gesture_get_dy(gevent);
 	scale = libinput_event_gesture_get_scale(gevent);
-	ck_assert(dx == 0.0);
-	ck_assert(dy == 0.0);
-	ck_assert(scale == 1.0);
+	litest_assert(dx == 0.0);
+	litest_assert(dy == 0.0);
+	litest_assert(scale == 1.0);
 
 	libinput_event_destroy(event);
 
@@ -626,25 +625,25 @@ test_gesture_pinch_4fg(int cardinal, enum hold_gesture_behaviour hold)
 		oldscale = scale;
 		scale = libinput_event_gesture_get_scale(gevent);
 
-		ck_assert(scale < oldscale);
+		litest_assert(scale < oldscale);
 
 		angle = libinput_event_gesture_get_angle_delta(gevent);
-		ck_assert_double_le(fabs(angle), 1.0);
+		litest_assert_double_le(fabs(angle), 1.0);
 
 		libinput_event_destroy(event);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
 	litest_touch_up(dev, 0);
 	litest_touch_up(dev, 1);
 	litest_touch_up(dev, 2);
 	litest_touch_up(dev, 3);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
 					 LIBINPUT_EVENT_GESTURE_PINCH_END,
 					 4);
-	ck_assert(!libinput_event_gesture_get_cancelled(gevent));
+	litest_assert(!libinput_event_gesture_get_cancelled(gevent));
 	libinput_event_destroy(event);
 }
 
@@ -694,7 +693,7 @@ test_gesture_spread(int cardinal, enum hold_gesture_behaviour hold)
 
 	litest_touch_down(dev, 0, 50 + dir_x, 50 + dir_y);
 	litest_touch_down(dev, 1, 50 - dir_x, 50 - dir_y);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	if (hold == HOLD_GESTURE_REQUIRE)
 		litest_timeout_gesture_hold();
@@ -718,7 +717,7 @@ test_gesture_spread(int cardinal, enum hold_gesture_behaviour hold)
 				  50 - dir_x,
 				  50 - dir_y);
 		litest_pop_event_frame(dev);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
 	if (hold == HOLD_GESTURE_REQUIRE) {
@@ -737,9 +736,9 @@ test_gesture_spread(int cardinal, enum hold_gesture_behaviour hold)
 	dx = libinput_event_gesture_get_dx(gevent);
 	dy = libinput_event_gesture_get_dy(gevent);
 	scale = libinput_event_gesture_get_scale(gevent);
-	ck_assert(dx == 0.0);
-	ck_assert(dy == 0.0);
-	ck_assert(scale == 1.0);
+	litest_assert(dx == 0.0);
+	litest_assert(dy == 0.0);
+	litest_assert(scale == 1.0);
 
 	libinput_event_destroy(event);
 
@@ -749,23 +748,23 @@ test_gesture_spread(int cardinal, enum hold_gesture_behaviour hold)
 						 2);
 		oldscale = scale;
 		scale = libinput_event_gesture_get_scale(gevent);
-		ck_assert(scale > oldscale);
+		litest_assert(scale > oldscale);
 
 		angle = libinput_event_gesture_get_angle_delta(gevent);
-		ck_assert_double_le(fabs(angle), 1.0);
+		litest_assert_double_le(fabs(angle), 1.0);
 
 		libinput_event_destroy(event);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
 	litest_touch_up(dev, 0);
 	litest_touch_up(dev, 1);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
 					 LIBINPUT_EVENT_GESTURE_PINCH_END,
 					 2);
-	ck_assert(!libinput_event_gesture_get_cancelled(gevent));
+	litest_assert(!libinput_event_gesture_get_cancelled(gevent));
 	libinput_event_destroy(event);
 }
 
@@ -786,7 +785,7 @@ test_gesture_3fg_buttonarea_scroll(enum hold_gesture_behaviour hold)
 	litest_touch_down(dev, 1, 30, 20);
 	/* third finger in btnarea */
 	litest_touch_down(dev, 2, 50, 99);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	if (hold == HOLD_GESTURE_REQUIRE)
 		litest_timeout_gesture_hold();
@@ -795,7 +794,7 @@ test_gesture_3fg_buttonarea_scroll(enum hold_gesture_behaviour hold)
 
 	litest_touch_up(dev, 0);
 	litest_touch_up(dev, 1);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	if (hold == HOLD_GESTURE_REQUIRE) {
 		litest_assert_gesture_event(li,
@@ -838,7 +837,7 @@ test_gesture_hold(int nfingers)
 		break;
 	}
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_timeout_gesture_hold();
 
 	if (libinput_device_has_capability(dev->libinput_device,
@@ -865,7 +864,7 @@ test_gesture_hold(int nfingers)
 		break;
 	}
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	if (libinput_device_has_capability(dev->libinput_device,
 					   LIBINPUT_DEVICE_CAP_GESTURE)) {
 		litest_assert_gesture_event(li,
@@ -903,7 +902,7 @@ test_gesture_hold_cancel(int nfingers)
 		break;
 	}
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_timeout_gesture_hold();
 
 	litest_touch_up(dev, last_finger);
@@ -927,10 +926,10 @@ START_TEST(gestures_cap)
 	struct libinput_device *device = dev->libinput_device;
 
 	if (libevdev_has_property(dev->evdev, INPUT_PROP_SEMI_MT))
-		ck_assert(!libinput_device_has_capability(device,
+		litest_assert(!libinput_device_has_capability(device,
 					  LIBINPUT_DEVICE_CAP_GESTURE));
 	else
-		ck_assert(libinput_device_has_capability(device,
+		litest_assert(libinput_device_has_capability(device,
 					 LIBINPUT_DEVICE_CAP_GESTURE));
 }
 END_TEST
@@ -940,7 +939,7 @@ START_TEST(gestures_nocap)
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 
-	ck_assert(!libinput_device_has_capability(device,
+	litest_assert(!libinput_device_has_capability(device,
 						  LIBINPUT_DEVICE_CAP_GESTURE));
 }
 END_TEST
@@ -976,7 +975,7 @@ START_TEST(gestures_swipe_3fg_btntool)
 	    !libevdev_has_event_code(dev->evdev, EV_KEY, BTN_TOOL_TRIPLETAP) ||
 	    !libinput_device_has_capability(dev->libinput_device,
 					    LIBINPUT_DEVICE_CAP_GESTURE))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	dir_x = cardinals[cardinal][0];
 	dir_y = cardinals[cardinal][1];
@@ -989,9 +988,9 @@ START_TEST(gestures_swipe_3fg_btntool)
 	litest_event(dev, EV_KEY, BTN_TOOL_TRIPLETAP, 1);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_touch_move_two_touches(dev, 40, 40, 50, 40, dir_x, dir_y, 10);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
@@ -999,8 +998,8 @@ START_TEST(gestures_swipe_3fg_btntool)
 					 3);
 	dx = libinput_event_gesture_get_dx(gevent);
 	dy = libinput_event_gesture_get_dy(gevent);
-	ck_assert(dx == 0.0);
-	ck_assert(dy == 0.0);
+	litest_assert(dx == 0.0);
+	litest_assert(dy == 0.0);
 	libinput_event_destroy(event);
 
 	while ((event = libinput_get_event(li)) != NULL) {
@@ -1011,46 +1010,46 @@ START_TEST(gestures_swipe_3fg_btntool)
 		dx = libinput_event_gesture_get_dx(gevent);
 		dy = libinput_event_gesture_get_dy(gevent);
 		if (dir_x == 0.0)
-			ck_assert(dx == 0.0);
+			litest_assert(dx == 0.0);
 		else if (dir_x < 0.0)
-			ck_assert(dx < 0.0);
+			litest_assert(dx < 0.0);
 		else if (dir_x > 0.0)
-			ck_assert(dx > 0.0);
+			litest_assert(dx > 0.0);
 
 		if (dir_y == 0.0)
-			ck_assert(dy == 0.0);
+			litest_assert(dy == 0.0);
 		else if (dir_y < 0.0)
-			ck_assert(dy < 0.0);
+			litest_assert(dy < 0.0);
 		else if (dir_y > 0.0)
-			ck_assert(dy > 0.0);
+			litest_assert(dy > 0.0);
 
 		dx = libinput_event_gesture_get_dx_unaccelerated(gevent);
 		dy = libinput_event_gesture_get_dy_unaccelerated(gevent);
 		if (dir_x == 0.0)
-			ck_assert(dx == 0.0);
+			litest_assert(dx == 0.0);
 		else if (dir_x < 0.0)
-			ck_assert(dx < 0.0);
+			litest_assert(dx < 0.0);
 		else if (dir_x > 0.0)
-			ck_assert(dx > 0.0);
+			litest_assert(dx > 0.0);
 
 		if (dir_y == 0.0)
-			ck_assert(dy == 0.0);
+			litest_assert(dy == 0.0);
 		else if (dir_y < 0.0)
-			ck_assert(dy < 0.0);
+			litest_assert(dy < 0.0);
 		else if (dir_y > 0.0)
-			ck_assert(dy > 0.0);
+			litest_assert(dy > 0.0);
 
 		libinput_event_destroy(event);
 	}
 
 	litest_touch_up(dev, 0);
 	litest_touch_up(dev, 1);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
 					 LIBINPUT_EVENT_GESTURE_SWIPE_END,
 					 3);
-	ck_assert(!libinput_event_gesture_get_cancelled(gevent));
+	litest_assert(!libinput_event_gesture_get_cancelled(gevent));
 	libinput_event_destroy(event);
 }
 END_TEST
@@ -1066,7 +1065,7 @@ START_TEST(gestures_swipe_3fg_btntool_pinch_like)
 	    !libevdev_has_event_code(dev->evdev, EV_KEY, BTN_TOOL_TRIPLETAP) ||
 	    !libinput_device_has_capability(dev->libinput_device,
 					    LIBINPUT_DEVICE_CAP_GESTURE))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_drain_events(li);
 
@@ -1078,9 +1077,9 @@ START_TEST(gestures_swipe_3fg_btntool_pinch_like)
 	litest_event(dev, EV_KEY, BTN_TOOL_TRIPLETAP, 1);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_touch_move_to(dev, 0, 20, 60, 10, 80, 20);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
 	litest_is_gesture_event(event, LIBINPUT_EVENT_GESTURE_SWIPE_BEGIN, 3);
@@ -1095,12 +1094,12 @@ START_TEST(gestures_swipe_3fg_btntool_pinch_like)
 
 	litest_touch_up(dev, 0);
 	litest_touch_up(dev, 1);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
 					 LIBINPUT_EVENT_GESTURE_SWIPE_END,
 					 3);
-	ck_assert(!libinput_event_gesture_get_cancelled(gevent));
+	litest_assert(!libinput_event_gesture_get_cancelled(gevent));
 	libinput_event_destroy(event);
 }
 END_TEST
@@ -1136,7 +1135,7 @@ START_TEST(gestures_swipe_4fg_btntool)
 	    !libevdev_has_event_code(dev->evdev, EV_KEY, BTN_TOOL_QUADTAP) ||
 	    !libinput_device_has_capability(dev->libinput_device,
 					    LIBINPUT_DEVICE_CAP_GESTURE))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	dir_x = cardinals[cardinal][0];
 	dir_y = cardinals[cardinal][1];
@@ -1149,9 +1148,9 @@ START_TEST(gestures_swipe_4fg_btntool)
 	litest_event(dev, EV_KEY, BTN_TOOL_QUADTAP, 1);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_touch_move_two_touches(dev, 40, 40, 50, 40, dir_x, dir_y, 10);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
@@ -1159,8 +1158,8 @@ START_TEST(gestures_swipe_4fg_btntool)
 					 4);
 	dx = libinput_event_gesture_get_dx(gevent);
 	dy = libinput_event_gesture_get_dy(gevent);
-	ck_assert(dx == 0.0);
-	ck_assert(dy == 0.0);
+	litest_assert(dx == 0.0);
+	litest_assert(dy == 0.0);
 	libinput_event_destroy(event);
 
 	while ((event = libinput_get_event(li)) != NULL) {
@@ -1171,46 +1170,46 @@ START_TEST(gestures_swipe_4fg_btntool)
 		dx = libinput_event_gesture_get_dx(gevent);
 		dy = libinput_event_gesture_get_dy(gevent);
 		if (dir_x == 0.0)
-			ck_assert(dx == 0.0);
+			litest_assert(dx == 0.0);
 		else if (dir_x < 0.0)
-			ck_assert(dx < 0.0);
+			litest_assert(dx < 0.0);
 		else if (dir_x > 0.0)
-			ck_assert(dx > 0.0);
+			litest_assert(dx > 0.0);
 
 		if (dir_y == 0.0)
-			ck_assert(dy == 0.0);
+			litest_assert(dy == 0.0);
 		else if (dir_y < 0.0)
-			ck_assert(dy < 0.0);
+			litest_assert(dy < 0.0);
 		else if (dir_y > 0.0)
-			ck_assert(dy > 0.0);
+			litest_assert(dy > 0.0);
 
 		dx = libinput_event_gesture_get_dx_unaccelerated(gevent);
 		dy = libinput_event_gesture_get_dy_unaccelerated(gevent);
 		if (dir_x == 0.0)
-			ck_assert(dx == 0.0);
+			litest_assert(dx == 0.0);
 		else if (dir_x < 0.0)
-			ck_assert(dx < 0.0);
+			litest_assert(dx < 0.0);
 		else if (dir_x > 0.0)
-			ck_assert(dx > 0.0);
+			litest_assert(dx > 0.0);
 
 		if (dir_y == 0.0)
-			ck_assert(dy == 0.0);
+			litest_assert(dy == 0.0);
 		else if (dir_y < 0.0)
-			ck_assert(dy < 0.0);
+			litest_assert(dy < 0.0);
 		else if (dir_y > 0.0)
-			ck_assert(dy > 0.0);
+			litest_assert(dy > 0.0);
 
 		libinput_event_destroy(event);
 	}
 
 	litest_touch_up(dev, 0);
 	litest_touch_up(dev, 1);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
 					 LIBINPUT_EVENT_GESTURE_SWIPE_END,
 					 4);
-	ck_assert(!libinput_event_gesture_get_cancelled(gevent));
+	litest_assert(!libinput_event_gesture_get_cancelled(gevent));
 	libinput_event_destroy(event);
 }
 END_TEST
@@ -1252,24 +1251,24 @@ START_TEST(gestures_time_usec)
 	uint64_t time_usec;
 
 	if (litest_slot_count(dev) < 3)
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_drain_events(li);
 
 	litest_touch_down(dev, 0, 40, 40);
 	litest_touch_down(dev, 1, 50, 40);
 	litest_touch_down(dev, 2, 60, 40);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_touch_move_three_touches(dev, 40, 40, 50, 40, 60, 40, 0, 30,
 					30);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
 	gevent = litest_is_gesture_event(event,
 					 LIBINPUT_EVENT_GESTURE_SWIPE_BEGIN,
 					 3);
 	time_usec = libinput_event_gesture_get_time_usec(gevent);
-	ck_assert_int_eq(libinput_event_gesture_get_time(gevent),
+	litest_assert_int_eq(libinput_event_gesture_get_time(gevent),
 			 (uint32_t) (time_usec / 1000));
 	libinput_event_destroy(event);
 }
@@ -1287,7 +1286,7 @@ START_TEST(gestures_3fg_buttonarea_scroll_btntool)
 	struct libinput *li = dev->libinput;
 
 	if (litest_slot_count(dev) > 2)
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_enable_buttonareas(dev);
 	litest_enable_2fg_scroll(dev);
@@ -1299,11 +1298,11 @@ START_TEST(gestures_3fg_buttonarea_scroll_btntool)
 	litest_event(dev, EV_KEY, BTN_TOOL_DOUBLETAP, 0);
 	litest_event(dev, EV_KEY, BTN_TOOL_TRIPLETAP, 1);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_touch_move_to(dev, 1, 30, 20, 30, 70, 10);
 
 	litest_touch_up(dev, 1);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_assert_scroll(li,
 			     LIBINPUT_EVENT_POINTER_SCROLL_FINGER,
 			     LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL,
@@ -1337,20 +1336,20 @@ START_TEST(gestures_swipe_3fg_unaccel)
 	const double max_factor = 5.34;
 
 	if (litest_slot_count(dev) < 3)
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_drain_events(li);
 	litest_touch_down(dev, 0, 40, 20);
 	litest_touch_down(dev, 1, 50, 20);
 	litest_touch_down(dev, 2, 60, 20);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_touch_move_three_touches(dev,
 					40, 20,
 					50, 20,
 					60, 20,
 					30, 40,
 					10);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
 	litest_is_gesture_event(event,
@@ -1371,8 +1370,8 @@ START_TEST(gestures_swipe_3fg_unaccel)
 		ux = libinput_event_gesture_get_dx_unaccelerated(gevent);
 		uy = libinput_event_gesture_get_dy_unaccelerated(gevent);
 
-		ck_assert_double_ne(ux, 0.0);
-		ck_assert_double_ne(uy, 0.0);
+		litest_assert_double_ne(ux, 0.0);
+		litest_assert_double_ne(uy, 0.0);
 
 		if (!reference_ux)
 			reference_ux = ux;
@@ -1383,21 +1382,21 @@ START_TEST(gestures_swipe_3fg_unaccel)
 		 * event, but we have rounding errors since we only control
 		 * input data as percentage of the touchpad size.
 		 * so we just eyeball it */
-		ck_assert_double_gt(ux, reference_ux - 2);
-		ck_assert_double_lt(ux, reference_ux + 2);
-		ck_assert_double_gt(uy, reference_uy - 2);
-		ck_assert_double_lt(uy, reference_uy + 2);
+		litest_assert_double_gt(ux, reference_ux - 2);
+		litest_assert_double_lt(ux, reference_ux + 2);
+		litest_assert_double_gt(uy, reference_uy - 2);
+		litest_assert_double_lt(uy, reference_uy + 2);
 
 		/* All our touchpads are large enough to make this is a fast
 		 * swipe, we don't expect deceleration, unaccel should
 		 * always be less than accel delta */
-		ck_assert_double_lt(ux, dx);
-		ck_assert_double_lt(ux, dx);
+		litest_assert_double_lt(ux, dx);
+		litest_assert_double_lt(ux, dx);
 
 		/* Check our accelerated delta is within the expected
 		 * maximum. */
-		ck_assert_double_lt(dx, ux * max_factor);
-		ck_assert_double_lt(dy, uy * max_factor);
+		litest_assert_double_lt(dx, ux * max_factor);
+		litest_assert_double_lt(dy, uy * max_factor);
 
 		libinput_event_destroy(event);
 	} while ((event = libinput_get_event(li)));
@@ -1413,11 +1412,11 @@ START_TEST(gestures_hold_config_default_disabled)
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 
-	ck_assert_int_eq(libinput_device_config_gesture_hold_is_available(device),
+	litest_assert_int_eq(libinput_device_config_gesture_hold_is_available(device),
 			 0);
-	ck_assert_int_eq(libinput_device_config_gesture_get_hold_default_enabled(device),
+	litest_assert_enum_eq(libinput_device_config_gesture_get_hold_default_enabled(device),
 			 LIBINPUT_CONFIG_HOLD_DISABLED);
-	ck_assert_int_eq(libinput_device_config_gesture_get_hold_default_enabled(device),
+	litest_assert_enum_eq(libinput_device_config_gesture_get_hold_default_enabled(device),
 			 LIBINPUT_CONFIG_HOLD_DISABLED);
 }
 END_TEST
@@ -1427,11 +1426,11 @@ START_TEST(gestures_hold_config_default_enabled)
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 
-	ck_assert_int_eq(libinput_device_config_gesture_hold_is_available(device),
+	litest_assert_int_eq(libinput_device_config_gesture_hold_is_available(device),
 			 1);
-	ck_assert_int_eq(libinput_device_config_gesture_get_hold_default_enabled(device),
+	litest_assert_enum_eq(libinput_device_config_gesture_get_hold_default_enabled(device),
 			 LIBINPUT_CONFIG_HOLD_ENABLED);
-	ck_assert_int_eq(libinput_device_config_gesture_get_hold_enabled(device),
+	litest_assert_enum_eq(libinput_device_config_gesture_get_hold_enabled(device),
 			 LIBINPUT_CONFIG_HOLD_ENABLED);
 }
 END_TEST
@@ -1441,9 +1440,9 @@ START_TEST(gestures_hold_config_set_invalid)
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 
-	ck_assert_int_eq(libinput_device_config_gesture_set_hold_enabled(device, -1),
+	litest_assert_enum_eq(libinput_device_config_gesture_set_hold_enabled(device, -1),
 			 LIBINPUT_CONFIG_STATUS_INVALID);
-	ck_assert_int_eq(libinput_device_config_gesture_set_hold_enabled(device, 2),
+	litest_assert_enum_eq(libinput_device_config_gesture_set_hold_enabled(device, 2),
 			 LIBINPUT_CONFIG_STATUS_INVALID);
 }
 END_TEST
@@ -1453,13 +1452,13 @@ START_TEST(gestures_hold_config_is_available)
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 
-	ck_assert_int_eq(libinput_device_config_gesture_hold_is_available(device),
+	litest_assert_int_eq(libinput_device_config_gesture_hold_is_available(device),
 			 1);
-	ck_assert_int_eq(libinput_device_config_gesture_get_hold_enabled(device),
+	litest_assert_enum_eq(libinput_device_config_gesture_get_hold_enabled(device),
 			 LIBINPUT_CONFIG_HOLD_ENABLED);
-	ck_assert_int_eq(libinput_device_config_gesture_set_hold_enabled(device, LIBINPUT_CONFIG_HOLD_DISABLED),
+	litest_assert_enum_eq(libinput_device_config_gesture_set_hold_enabled(device, LIBINPUT_CONFIG_HOLD_DISABLED),
 			 LIBINPUT_CONFIG_STATUS_SUCCESS);
-	ck_assert_int_eq(libinput_device_config_gesture_get_hold_enabled(device),
+	litest_assert_enum_eq(libinput_device_config_gesture_get_hold_enabled(device),
 			 LIBINPUT_CONFIG_HOLD_DISABLED);
 }
 END_TEST
@@ -1469,13 +1468,13 @@ START_TEST(gestures_hold_config_is_not_available)
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 
-	ck_assert_int_eq(libinput_device_config_gesture_hold_is_available(device),
+	litest_assert_int_eq(libinput_device_config_gesture_hold_is_available(device),
 			 0);
-	ck_assert_int_eq(libinput_device_config_gesture_get_hold_enabled(device),
+	litest_assert_enum_eq(libinput_device_config_gesture_get_hold_enabled(device),
 			 LIBINPUT_CONFIG_HOLD_DISABLED);
-	ck_assert_int_eq(libinput_device_config_gesture_set_hold_enabled(device, LIBINPUT_CONFIG_HOLD_ENABLED),
+	litest_assert_enum_eq(libinput_device_config_gesture_set_hold_enabled(device, LIBINPUT_CONFIG_HOLD_ENABLED),
 			 LIBINPUT_CONFIG_STATUS_UNSUPPORTED);
-	ck_assert_int_eq(libinput_device_config_gesture_set_hold_enabled(device, LIBINPUT_CONFIG_HOLD_DISABLED),
+	litest_assert_enum_eq(libinput_device_config_gesture_set_hold_enabled(device, LIBINPUT_CONFIG_HOLD_DISABLED),
 			 LIBINPUT_CONFIG_STATUS_SUCCESS);
 }
 END_TEST
@@ -1587,17 +1586,17 @@ START_TEST(gestures_hold_once_on_double_tap)
 
 	if (!libinput_device_has_capability(dev->libinput_device,
 					    LIBINPUT_DEVICE_CAP_GESTURE))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_enable_tap(dev->libinput_device);
 	litest_drain_events(li);
 
 	/* First tap, a hold gesture must be generated */
 	litest_touch_down(dev, 0, 50, 50);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_timeout_gesture_quick_hold();
 	litest_touch_up(dev, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_assert_gesture_event(li,
 				    LIBINPUT_EVENT_GESTURE_HOLD_BEGIN,
@@ -1614,7 +1613,7 @@ START_TEST(gestures_hold_once_on_double_tap)
 	/* Double tap, don't generate an extra hold gesture */
 	litest_touch_down(dev, 0, 50, 50);
 	litest_touch_up(dev, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_timeout_gesture_quick_hold();
 
 	litest_assert_button_event(li, BTN_LEFT,
@@ -1634,11 +1633,11 @@ START_TEST(gestures_hold_once_tap_n_drag)
 	unsigned int button = 0;
 
 	if (nfingers > litest_slot_count(dev))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	if (!libinput_device_has_capability(dev->libinput_device,
 					    LIBINPUT_DEVICE_CAP_GESTURE))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_enable_tap(dev->libinput_device);
 	litest_disable_drag_lock(dev->libinput_device);
@@ -1669,7 +1668,7 @@ START_TEST(gestures_hold_once_tap_n_drag)
 		litest_touch_down(dev, 0, 40, 30);
 		break;
 	}
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_timeout_gesture_quick_hold();
 
 	switch (nfingers) {
@@ -1683,7 +1682,7 @@ START_TEST(gestures_hold_once_tap_n_drag)
 		litest_touch_up(dev, 0);
 		break;
 	}
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	/* "Quick" hold gestures are only generated when using 1 or 2 fingers */
 	if (nfingers == 1 || nfingers == 2) {
@@ -1698,14 +1697,14 @@ START_TEST(gestures_hold_once_tap_n_drag)
 	/* Tap and drag, don't generate an extra hold gesture */
 	litest_touch_down(dev, 0, 50, 50);
 	litest_touch_move_to(dev, 0, 50, 50, 80, 80, 20);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_assert_button_event(li, button,
 				   LIBINPUT_BUTTON_STATE_PRESSED);
 	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	litest_touch_up(dev, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_assert_button_event(li, button,
 				   LIBINPUT_BUTTON_STATE_RELEASED);
@@ -1720,27 +1719,27 @@ START_TEST(gestures_hold_and_motion_before_timeout)
 
 	if (!libinput_device_has_capability(dev->libinput_device,
 					    LIBINPUT_DEVICE_CAP_GESTURE))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_drain_events(li);
 
 	litest_touch_down(dev, 0, 50, 50);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_touch_move_to(dev, 0, 50, 50, 51, 51, 1);
 	litest_touch_move_to(dev, 0, 51, 51, 50, 50, 1);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_timeout_gesture_quick_hold();
 
-	litest_drain_events_of_type(li, LIBINPUT_EVENT_POINTER_MOTION, -1);
+	litest_drain_events_of_type(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	litest_assert_gesture_event(li,
 				    LIBINPUT_EVENT_GESTURE_HOLD_BEGIN,
 				    1);
 
 	litest_touch_up(dev, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_assert_gesture_event(li,
 				    LIBINPUT_EVENT_GESTURE_HOLD_END,
@@ -1756,12 +1755,12 @@ START_TEST(gestures_hold_and_motion_after_timeout)
 
 	if (!libinput_device_has_capability(dev->libinput_device,
 					    LIBINPUT_DEVICE_CAP_GESTURE))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_drain_events(li);
 
 	litest_touch_down(dev, 0, 50, 50);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_timeout_gesture_quick_hold();
 
 	litest_assert_gesture_event(li,
@@ -1770,11 +1769,11 @@ START_TEST(gestures_hold_and_motion_after_timeout)
 
 	litest_touch_move_to(dev, 0, 50, 50, 51, 51, 1);
 	litest_touch_move_to(dev, 0, 51, 51, 50, 50, 1);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_assert_only_typed_events(li, LIBINPUT_EVENT_POINTER_MOTION);
 
 	litest_touch_up(dev, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_assert_gesture_event(li,
 				    LIBINPUT_EVENT_GESTURE_HOLD_END,
