@@ -23,7 +23,6 @@
 
 #include <config.h>
 
-#include <check.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <libinput.h>
@@ -109,7 +108,7 @@ START_TEST(event_conversion_device_notify)
 	litest_restore_log_handler(li); /* use the default litest handler */
 	libinput_path_add_device(li, libevdev_uinput_get_devnode(uinput));
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	libinput_suspend(li);
 	libinput_resume(li);
 
@@ -123,7 +122,7 @@ START_TEST(event_conversion_device_notify)
 			struct libinput_event *base;
 			dn = libinput_event_get_device_notify_event(event);
 			base = libinput_event_device_notify_get_base_event(dn);
-			ck_assert(event == base);
+			litest_assert(event == base);
 
 			if (type == LIBINPUT_EVENT_DEVICE_ADDED)
 				device_added++;
@@ -131,13 +130,13 @@ START_TEST(event_conversion_device_notify)
 				device_removed++;
 
 			litest_disable_log_handler(li);
-			ck_assert(libinput_event_get_pointer_event(event) == NULL);
-			ck_assert(libinput_event_get_keyboard_event(event) == NULL);
-			ck_assert(libinput_event_get_touch_event(event) == NULL);
-			ck_assert(libinput_event_get_gesture_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_tool_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_pad_event(event) == NULL);
-			ck_assert(libinput_event_get_switch_event(event) == NULL);
+			litest_assert(libinput_event_get_pointer_event(event) == NULL);
+			litest_assert(libinput_event_get_keyboard_event(event) == NULL);
+			litest_assert(libinput_event_get_touch_event(event) == NULL);
+			litest_assert(libinput_event_get_gesture_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_tool_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_pad_event(event) == NULL);
+			litest_assert(libinput_event_get_switch_event(event) == NULL);
 			litest_restore_log_handler(li);
 		}
 
@@ -147,8 +146,8 @@ START_TEST(event_conversion_device_notify)
 	litest_destroy_context(li);
 	libevdev_uinput_destroy(uinput);
 
-	ck_assert_int_gt(device_added, 0);
-	ck_assert_int_gt(device_removed, 0);
+	litest_assert_int_gt(device_added, 0);
+	litest_assert_int_gt(device_removed, 0);
 }
 END_TEST
 
@@ -169,7 +168,7 @@ START_TEST(event_conversion_pointer)
 	litest_event(dev, EV_KEY, BTN_LEFT, 1);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	while ((event = libinput_get_event(li))) {
 		enum libinput_event_type type;
@@ -181,7 +180,7 @@ START_TEST(event_conversion_pointer)
 			struct libinput_event *base;
 			p = libinput_event_get_pointer_event(event);
 			base = libinput_event_pointer_get_base_event(p);
-			ck_assert(event == base);
+			litest_assert(event == base);
 
 			if (type == LIBINPUT_EVENT_POINTER_MOTION)
 				motion++;
@@ -189,20 +188,20 @@ START_TEST(event_conversion_pointer)
 				button++;
 
 			litest_disable_log_handler(li);
-			ck_assert(libinput_event_get_device_notify_event(event) == NULL);
-			ck_assert(libinput_event_get_keyboard_event(event) == NULL);
-			ck_assert(libinput_event_get_touch_event(event) == NULL);
-			ck_assert(libinput_event_get_gesture_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_tool_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_pad_event(event) == NULL);
-			ck_assert(libinput_event_get_switch_event(event) == NULL);
+			litest_assert(libinput_event_get_device_notify_event(event) == NULL);
+			litest_assert(libinput_event_get_keyboard_event(event) == NULL);
+			litest_assert(libinput_event_get_touch_event(event) == NULL);
+			litest_assert(libinput_event_get_gesture_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_tool_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_pad_event(event) == NULL);
+			litest_assert(libinput_event_get_switch_event(event) == NULL);
 			litest_restore_log_handler(li);
 		}
 		libinput_event_destroy(event);
 	}
 
-	ck_assert_int_gt(motion, 0);
-	ck_assert_int_gt(button, 0);
+	litest_assert_int_gt(motion, 0);
+	litest_assert_int_gt(button, 0);
 }
 END_TEST
 
@@ -221,7 +220,7 @@ START_TEST(event_conversion_pointer_abs)
 	litest_event(dev, EV_ABS, ABS_Y, 30);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	while ((event = libinput_get_event(li))) {
 		enum libinput_event_type type;
@@ -233,7 +232,7 @@ START_TEST(event_conversion_pointer_abs)
 			struct libinput_event *base;
 			p = libinput_event_get_pointer_event(event);
 			base = libinput_event_pointer_get_base_event(p);
-			ck_assert(event == base);
+			litest_assert(event == base);
 
 			if (type == LIBINPUT_EVENT_POINTER_MOTION_ABSOLUTE)
 				motion++;
@@ -241,20 +240,20 @@ START_TEST(event_conversion_pointer_abs)
 				button++;
 
 			litest_disable_log_handler(li);
-			ck_assert(libinput_event_get_device_notify_event(event) == NULL);
-			ck_assert(libinput_event_get_keyboard_event(event) == NULL);
-			ck_assert(libinput_event_get_touch_event(event) == NULL);
-			ck_assert(libinput_event_get_gesture_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_tool_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_pad_event(event) == NULL);
-			ck_assert(libinput_event_get_switch_event(event) == NULL);
+			litest_assert(libinput_event_get_device_notify_event(event) == NULL);
+			litest_assert(libinput_event_get_keyboard_event(event) == NULL);
+			litest_assert(libinput_event_get_touch_event(event) == NULL);
+			litest_assert(libinput_event_get_gesture_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_tool_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_pad_event(event) == NULL);
+			litest_assert(libinput_event_get_switch_event(event) == NULL);
 			litest_restore_log_handler(li);
 		}
 		libinput_event_destroy(event);
 	}
 
-	ck_assert_int_gt(motion, 0);
-	ck_assert_int_gt(button, 0);
+	litest_assert_int_gt(motion, 0);
+	litest_assert_int_gt(button, 0);
 }
 END_TEST
 
@@ -270,7 +269,7 @@ START_TEST(event_conversion_key)
 	litest_event(dev, EV_KEY, KEY_A, 0);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	while ((event = libinput_get_event(li))) {
 		enum libinput_event_type type;
@@ -281,24 +280,24 @@ START_TEST(event_conversion_key)
 			struct libinput_event *base;
 			k = libinput_event_get_keyboard_event(event);
 			base = libinput_event_keyboard_get_base_event(k);
-			ck_assert(event == base);
+			litest_assert(event == base);
 
 			key++;
 
 			litest_disable_log_handler(li);
-			ck_assert(libinput_event_get_device_notify_event(event) == NULL);
-			ck_assert(libinput_event_get_pointer_event(event) == NULL);
-			ck_assert(libinput_event_get_touch_event(event) == NULL);
-			ck_assert(libinput_event_get_gesture_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_tool_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_pad_event(event) == NULL);
-			ck_assert(libinput_event_get_switch_event(event) == NULL);
+			litest_assert(libinput_event_get_device_notify_event(event) == NULL);
+			litest_assert(libinput_event_get_pointer_event(event) == NULL);
+			litest_assert(libinput_event_get_touch_event(event) == NULL);
+			litest_assert(libinput_event_get_gesture_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_tool_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_pad_event(event) == NULL);
+			litest_assert(libinput_event_get_switch_event(event) == NULL);
 			litest_restore_log_handler(li);
 		}
 		libinput_event_destroy(event);
 	}
 
-	ck_assert_int_gt(key, 0);
+	litest_assert_int_gt(key, 0);
 }
 END_TEST
 
@@ -309,7 +308,7 @@ START_TEST(event_conversion_touch)
 	struct libinput_event *event;
 	int touch = 0;
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_event(dev, EV_KEY, BTN_TOOL_FINGER, 1);
 	litest_event(dev, EV_KEY, BTN_TOUCH, 1);
@@ -321,7 +320,7 @@ START_TEST(event_conversion_touch)
 	litest_event(dev, EV_ABS, ABS_MT_POSITION_Y, 10);
 	litest_event(dev, EV_SYN, SYN_REPORT, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	while ((event = libinput_get_event(li))) {
 		enum libinput_event_type type;
@@ -333,24 +332,24 @@ START_TEST(event_conversion_touch)
 			struct libinput_event *base;
 			t = libinput_event_get_touch_event(event);
 			base = libinput_event_touch_get_base_event(t);
-			ck_assert(event == base);
+			litest_assert(event == base);
 
 			touch++;
 
 			litest_disable_log_handler(li);
-			ck_assert(libinput_event_get_device_notify_event(event) == NULL);
-			ck_assert(libinput_event_get_pointer_event(event) == NULL);
-			ck_assert(libinput_event_get_keyboard_event(event) == NULL);
-			ck_assert(libinput_event_get_gesture_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_tool_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_pad_event(event) == NULL);
-			ck_assert(libinput_event_get_switch_event(event) == NULL);
+			litest_assert(libinput_event_get_device_notify_event(event) == NULL);
+			litest_assert(libinput_event_get_pointer_event(event) == NULL);
+			litest_assert(libinput_event_get_keyboard_event(event) == NULL);
+			litest_assert(libinput_event_get_gesture_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_tool_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_pad_event(event) == NULL);
+			litest_assert(libinput_event_get_switch_event(event) == NULL);
 			litest_restore_log_handler(li);
 		}
 		libinput_event_destroy(event);
 	}
 
-	ck_assert_int_gt(touch, 0);
+	litest_assert_int_gt(touch, 0);
 }
 END_TEST
 
@@ -362,11 +361,11 @@ START_TEST(event_conversion_gesture)
 	int gestures = 0;
 	int i;
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_touch_down(dev, 0, 70, 30);
 	litest_touch_down(dev, 1, 30, 70);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_timeout_gesture_hold();
 
 	for (i = 0; i < 8; i++) {
@@ -374,7 +373,7 @@ START_TEST(event_conversion_gesture)
 		litest_touch_move(dev, 0, 70 - i * 5, 30 + i * 5);
 		litest_touch_move(dev, 1, 30 + i * 5, 70 - i * 5);
 		litest_pop_event_frame(dev);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
 	while ((event = libinput_get_event(li))) {
@@ -387,23 +386,23 @@ START_TEST(event_conversion_gesture)
 			struct libinput_event *base;
 			g = libinput_event_get_gesture_event(event);
 			base = libinput_event_gesture_get_base_event(g);
-			ck_assert(event == base);
+			litest_assert(event == base);
 
 			gestures++;
 
 			litest_disable_log_handler(li);
-			ck_assert(libinput_event_get_device_notify_event(event) == NULL);
-			ck_assert(libinput_event_get_pointer_event(event) == NULL);
-			ck_assert(libinput_event_get_keyboard_event(event) == NULL);
-			ck_assert(libinput_event_get_touch_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_pad_event(event) == NULL);
-			ck_assert(libinput_event_get_switch_event(event) == NULL);
+			litest_assert(libinput_event_get_device_notify_event(event) == NULL);
+			litest_assert(libinput_event_get_pointer_event(event) == NULL);
+			litest_assert(libinput_event_get_keyboard_event(event) == NULL);
+			litest_assert(libinput_event_get_touch_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_pad_event(event) == NULL);
+			litest_assert(libinput_event_get_switch_event(event) == NULL);
 			litest_restore_log_handler(li);
 		}
 		libinput_event_destroy(event);
 	}
 
-	ck_assert_int_gt(gestures, 0);
+	litest_assert_int_gt(gestures, 0);
 }
 END_TEST
 
@@ -423,7 +422,7 @@ START_TEST(event_conversion_tablet)
 	litest_button_click(dev, BTN_STYLUS, true);
 	litest_button_click(dev, BTN_STYLUS, false);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	while ((event = libinput_get_event(li))) {
 		enum libinput_event_type type;
@@ -435,23 +434,23 @@ START_TEST(event_conversion_tablet)
 			struct libinput_event *base;
 			t = libinput_event_get_tablet_tool_event(event);
 			base = libinput_event_tablet_tool_get_base_event(t);
-			ck_assert(event == base);
+			litest_assert(event == base);
 
 			events++;
 
 			litest_disable_log_handler(li);
-			ck_assert(libinput_event_get_device_notify_event(event) == NULL);
-			ck_assert(libinput_event_get_pointer_event(event) == NULL);
-			ck_assert(libinput_event_get_keyboard_event(event) == NULL);
-			ck_assert(libinput_event_get_touch_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_pad_event(event) == NULL);
-			ck_assert(libinput_event_get_switch_event(event) == NULL);
+			litest_assert(libinput_event_get_device_notify_event(event) == NULL);
+			litest_assert(libinput_event_get_pointer_event(event) == NULL);
+			litest_assert(libinput_event_get_keyboard_event(event) == NULL);
+			litest_assert(libinput_event_get_touch_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_pad_event(event) == NULL);
+			litest_assert(libinput_event_get_switch_event(event) == NULL);
 			litest_restore_log_handler(li);
 		}
 		libinput_event_destroy(event);
 	}
 
-	ck_assert_int_gt(events, 0);
+	litest_assert_int_gt(events, 0);
 }
 END_TEST
 
@@ -466,7 +465,7 @@ START_TEST(event_conversion_tablet_pad)
 	litest_pad_ring_start(dev, 10);
 	litest_pad_ring_end(dev);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	while ((event = libinput_get_event(li))) {
 		enum libinput_event_type type;
@@ -479,23 +478,23 @@ START_TEST(event_conversion_tablet_pad)
 
 			p = libinput_event_get_tablet_pad_event(event);
 			base = libinput_event_tablet_pad_get_base_event(p);
-			ck_assert(event == base);
+			litest_assert(event == base);
 
 			events++;
 
 			litest_disable_log_handler(li);
-			ck_assert(libinput_event_get_device_notify_event(event) == NULL);
-			ck_assert(libinput_event_get_pointer_event(event) == NULL);
-			ck_assert(libinput_event_get_keyboard_event(event) == NULL);
-			ck_assert(libinput_event_get_touch_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_tool_event(event) == NULL);
-			ck_assert(libinput_event_get_switch_event(event) == NULL);
+			litest_assert(libinput_event_get_device_notify_event(event) == NULL);
+			litest_assert(libinput_event_get_pointer_event(event) == NULL);
+			litest_assert(libinput_event_get_keyboard_event(event) == NULL);
+			litest_assert(libinput_event_get_touch_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_tool_event(event) == NULL);
+			litest_assert(libinput_event_get_switch_event(event) == NULL);
 			litest_restore_log_handler(li);
 		}
 		libinput_event_destroy(event);
 	}
 
-	ck_assert_int_gt(events, 0);
+	litest_assert_int_gt(events, 0);
 }
 END_TEST
 
@@ -512,7 +511,7 @@ START_TEST(event_conversion_switch)
 	litest_switch_action(dev,
 			     LIBINPUT_SWITCH_LID,
 			     LIBINPUT_SWITCH_STATE_OFF);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	while ((event = libinput_get_event(li))) {
 		enum libinput_event_type type;
@@ -523,24 +522,24 @@ START_TEST(event_conversion_switch)
 			struct libinput_event *base;
 			s = libinput_event_get_switch_event(event);
 			base = libinput_event_switch_get_base_event(s);
-			ck_assert(event == base);
+			litest_assert(event == base);
 
 			sw++;
 
 			litest_disable_log_handler(li);
-			ck_assert(libinput_event_get_device_notify_event(event) == NULL);
-			ck_assert(libinput_event_get_keyboard_event(event) == NULL);
-			ck_assert(libinput_event_get_pointer_event(event) == NULL);
-			ck_assert(libinput_event_get_touch_event(event) == NULL);
-			ck_assert(libinput_event_get_gesture_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_tool_event(event) == NULL);
-			ck_assert(libinput_event_get_tablet_pad_event(event) == NULL);
+			litest_assert(libinput_event_get_device_notify_event(event) == NULL);
+			litest_assert(libinput_event_get_keyboard_event(event) == NULL);
+			litest_assert(libinput_event_get_pointer_event(event) == NULL);
+			litest_assert(libinput_event_get_touch_event(event) == NULL);
+			litest_assert(libinput_event_get_gesture_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_tool_event(event) == NULL);
+			litest_assert(libinput_event_get_tablet_pad_event(event) == NULL);
 			litest_restore_log_handler(li);
 		}
 		libinput_event_destroy(event);
 	}
 
-	ck_assert_int_gt(sw, 0);
+	litest_assert_int_gt(sw, 0);
 }
 END_TEST
 
@@ -552,14 +551,14 @@ START_TEST(context_ref_counting)
 	 * free errors. */
 
 	li = libinput_path_create_context(&simple_interface, NULL);
-	ck_assert_notnull(li);
-	ck_assert_ptr_eq(libinput_unref(li), NULL);
+	litest_assert_notnull(li);
+	litest_assert_ptr_eq(libinput_unref(li), NULL);
 
 	li = libinput_path_create_context(&simple_interface, NULL);
-	ck_assert_notnull(li);
-	ck_assert_ptr_eq(libinput_ref(li), li);
-	ck_assert_ptr_eq(libinput_unref(li), li);
-	ck_assert_ptr_eq(libinput_unref(li), NULL);
+	litest_assert_notnull(li);
+	litest_assert_ptr_eq(libinput_ref(li), li);
+	litest_assert_ptr_eq(libinput_unref(li), li);
+	litest_assert_ptr_eq(libinput_unref(li), NULL);
 }
 END_TEST
 
@@ -575,12 +574,12 @@ START_TEST(config_status_string)
 
 	for (i = 0; i < ARRAY_LENGTH(strs) - 1; i++)
 		for (j = i + 1; j < ARRAY_LENGTH(strs); j++)
-			ck_assert_str_ne(strs[i], strs[j]);
+			litest_assert_str_ne(strs[i], strs[j]);
 
 	invalid = libinput_config_status_to_str(LIBINPUT_CONFIG_STATUS_INVALID + 1);
-	ck_assert(invalid == NULL);
+	litest_assert(invalid == NULL);
 	invalid = libinput_config_status_to_str(LIBINPUT_CONFIG_STATUS_SUCCESS - 1);
-	ck_assert(invalid == NULL);
+	litest_assert(invalid == NULL);
 }
 END_TEST
 
@@ -618,7 +617,7 @@ START_TEST(fd_no_event_leak)
 	path = libevdev_uinput_get_devnode(uinput);
 
 	fd = open(path, O_RDWR | O_NONBLOCK | O_CLOEXEC);
-	ck_assert_int_gt(fd, -1);
+	litest_assert_int_gt(fd, -1);
 
 	li = libinput_path_create_context(&leak_interface, &fd);
 	litest_restore_log_handler(li); /* use the default litest handler */
@@ -630,7 +629,7 @@ START_TEST(fd_no_event_leak)
 	libevdev_uinput_write_event(uinput, EV_REL, REL_X, 1);
 	libevdev_uinput_write_event(uinput, EV_SYN, SYN_REPORT, 0);
 	libinput_path_remove_device(device);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_drain_events(li);
 
 	/* Device is removed, but fd is still open. Queue an event, add a
@@ -638,13 +637,12 @@ START_TEST(fd_no_event_leak)
 	 * by libinput */
 	libevdev_uinput_write_event(uinput, EV_REL, REL_Y, 1);
 	libevdev_uinput_write_event(uinput, EV_SYN, SYN_REPORT, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	libinput_path_add_device(li, path);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
-	ck_assert_int_eq(libinput_event_get_type(event),
-			 LIBINPUT_EVENT_DEVICE_ADDED);
+	litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 	libinput_event_destroy(event);
 
 	litest_assert_empty_queue(li);
@@ -685,10 +683,10 @@ START_TEST(timer_offset_bug_warning)
 
 	user_data->private = &warning_triggered;
 	libinput_log_set_handler(li, timer_offset_warning);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	/* triggered for touch down and touch up */
-	ck_assert_int_eq(warning_triggered, 2);
+	litest_assert_int_eq(warning_triggered, 2);
 	litest_restore_log_handler(li);
 }
 END_TEST
@@ -722,10 +720,10 @@ START_TEST(timer_delay_bug_warning)
 		litest_event(dev, EV_REL, REL_X, -1);
 		litest_event(dev, EV_SYN, SYN_REPORT, 0);
 		msleep(21);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 	}
 
-	ck_assert_int_ge(warning_triggered, 1);
+	litest_assert_int_ge(warning_triggered, 1);
 	litest_restore_log_handler(li);
 }
 END_TEST
@@ -739,17 +737,17 @@ START_TEST(timer_flush)
 
 	touchpad = litest_add_device(li, LITEST_SYNAPTICS_TOUCHPAD);
 	litest_enable_tap(touchpad->libinput_device);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	keyboard = litest_add_device(li, LITEST_KEYBOARD);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_drain_events(li);
 
 	/* make sure tapping works */
 	litest_touch_down(touchpad, 0, 50, 50);
 	litest_touch_up(touchpad, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_timeout_tap();
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_assert_button_event(li, BTN_LEFT,
 				   LIBINPUT_BUTTON_STATE_PRESSED);
@@ -760,12 +758,12 @@ START_TEST(timer_flush)
 	/* make sure dwt-tap is ignored */
 	litest_keyboard_key(keyboard, KEY_A, true);
 	litest_keyboard_key(keyboard, KEY_A, false);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_touch_down(touchpad, 0, 50, 50);
 	litest_touch_up(touchpad, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_timeout_tap();
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_assert_only_typed_events(li, LIBINPUT_EVENT_KEYBOARD_KEY);
 
 	/* Ignore 'timer offset negative' warnings */
@@ -775,7 +773,7 @@ START_TEST(timer_flush)
 	   - send a key event
 	   - expire dwt
 	   - send a tap
-	   and then call libinput_dispatch(). libinput should notice that
+	   and then call litest_dispatch(). libinput should notice that
 	   the tap event came in after the timeout and thus acknowledge the
 	   tap.
 	 */
@@ -784,9 +782,9 @@ START_TEST(timer_flush)
 	litest_timeout_dwt_long();
 	litest_touch_down(touchpad, 0, 50, 50);
 	litest_touch_up(touchpad, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_timeout_tap();
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_restore_log_handler(li);
 
 	litest_assert_key_event(li, KEY_A, LIBINPUT_KEY_STATE_PRESSED);
@@ -814,7 +812,7 @@ START_TEST(udev_absinfo_override)
 	     found_mt_x = false, found_mt_y = false;
 
 	ud = libinput_device_get_udev_device(dev->libinput_device);
-	ck_assert_notnull(ud);
+	litest_assert_notnull(ud);
 
 	/* Custom checks for this special litest device only */
 
@@ -827,57 +825,57 @@ START_TEST(udev_absinfo_override)
 
 		if (streq(key, "EVDEV_ABS_00")) {
 			found_x = true;
-			ck_assert(streq(value, "1:1000:100:10"));
+			litest_assert(streq(value, "1:1000:100:10"));
 		}
 		if (streq(key, "EVDEV_ABS_01")) {
 			found_y = true;
-			ck_assert(streq(value, "2:2000:200:20"));
+			litest_assert(streq(value, "2:2000:200:20"));
 		}
 		if (streq(key, "EVDEV_ABS_35")) {
 			found_mt_x = true;
-			ck_assert(streq(value, "3:3000:300:30"));
+			litest_assert(streq(value, "3:3000:300:30"));
 		}
 		if (streq(key, "EVDEV_ABS_36")) {
 			found_mt_y = true;
-			ck_assert(streq(value, "4:4000:400:40"));
+			litest_assert(streq(value, "4:4000:400:40"));
 		}
 
 		entry = udev_list_entry_get_next(entry);
 	}
 	udev_device_unref(ud);
 
-	ck_assert(found_x);
-	ck_assert(found_y);
-	ck_assert(found_mt_x);
-	ck_assert(found_mt_y);
+	litest_assert(found_x);
+	litest_assert(found_y);
+	litest_assert(found_mt_x);
+	litest_assert(found_mt_y);
 
 	abs = libevdev_get_abs_info(evdev, ABS_X);
-	ck_assert_int_eq(abs->minimum, 1);
-	ck_assert_int_eq(abs->maximum, 1000);
-	ck_assert_int_eq(abs->resolution, 100);
+	litest_assert_int_eq(abs->minimum, 1);
+	litest_assert_int_eq(abs->maximum, 1000);
+	litest_assert_int_eq(abs->resolution, 100);
 	/* if everything goes well, we override the fuzz to 0 */
-	ck_assert_int_eq(abs->fuzz, 0);
+	litest_assert_int_eq(abs->fuzz, 0);
 
 	abs = libevdev_get_abs_info(evdev, ABS_Y);
-	ck_assert_int_eq(abs->minimum, 2);
-	ck_assert_int_eq(abs->maximum, 2000);
-	ck_assert_int_eq(abs->resolution, 200);
+	litest_assert_int_eq(abs->minimum, 2);
+	litest_assert_int_eq(abs->maximum, 2000);
+	litest_assert_int_eq(abs->resolution, 200);
 	/* if everything goes well, we override the fuzz to 0 */
-	ck_assert_int_eq(abs->fuzz, 0);
+	litest_assert_int_eq(abs->fuzz, 0);
 
 	abs = libevdev_get_abs_info(evdev, ABS_MT_POSITION_X);
-	ck_assert_int_eq(abs->minimum, 3);
-	ck_assert_int_eq(abs->maximum, 3000);
-	ck_assert_int_eq(abs->resolution, 300);
+	litest_assert_int_eq(abs->minimum, 3);
+	litest_assert_int_eq(abs->maximum, 3000);
+	litest_assert_int_eq(abs->resolution, 300);
 	/* if everything goes well, we override the fuzz to 0 */
-	ck_assert_int_eq(abs->fuzz, 0);
+	litest_assert_int_eq(abs->fuzz, 0);
 
 	abs = libevdev_get_abs_info(evdev, ABS_MT_POSITION_Y);
-	ck_assert_int_eq(abs->minimum, 4);
-	ck_assert_int_eq(abs->maximum, 4000);
-	ck_assert_int_eq(abs->resolution, 400);
+	litest_assert_int_eq(abs->minimum, 4);
+	litest_assert_int_eq(abs->maximum, 4000);
+	litest_assert_int_eq(abs->resolution, 400);
 	/* if everything goes well, we override the fuzz to 0 */
-	ck_assert_int_eq(abs->fuzz, 0);
+	litest_assert_int_eq(abs->fuzz, 0);
 }
 END_TEST
 
