@@ -23,7 +23,6 @@
 
 #include <config.h>
 
-#include <check.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <libinput.h>
@@ -42,7 +41,7 @@ START_TEST(pad_cap)
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 
-	ck_assert(libinput_device_has_capability(device,
+	litest_assert(libinput_device_has_capability(device,
 						 LIBINPUT_DEVICE_CAP_TABLET_PAD));
 
 }
@@ -53,7 +52,7 @@ START_TEST(pad_no_cap)
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 
-	ck_assert(!libinput_device_has_capability(device,
+	litest_assert(!libinput_device_has_capability(device,
 						  LIBINPUT_DEVICE_CAP_TABLET_PAD));
 }
 END_TEST
@@ -78,24 +77,23 @@ START_TEST(pad_time)
 
 		litest_button_click(dev, code, 1);
 		litest_button_click(dev, code, 0);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 
 		break;
 	}
 
 	if (!has_buttons)
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	ev = libinput_get_event(li);
-	ck_assert_notnull(ev);
-	ck_assert_int_eq(libinput_event_get_type(ev),
-			 LIBINPUT_EVENT_TABLET_PAD_BUTTON);
+	litest_assert_notnull(ev);
+	litest_assert_event_type(ev, LIBINPUT_EVENT_TABLET_PAD_BUTTON);
 	pev = libinput_event_get_tablet_pad_event(ev);
 	time = libinput_event_tablet_pad_get_time(pev);
 	time_usec = libinput_event_tablet_pad_get_time_usec(pev);
 
-	ck_assert(time != 0);
-	ck_assert(time == time_usec/1000);
+	litest_assert(time != 0);
+	litest_assert(time == time_usec/1000);
 
 	libinput_event_destroy(ev);
 
@@ -104,20 +102,19 @@ START_TEST(pad_time)
 
 	litest_button_click(dev, code, 1);
 	litest_button_click(dev, code, 0);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	ev = libinput_get_event(li);
-	ck_assert_int_eq(libinput_event_get_type(ev),
-			 LIBINPUT_EVENT_TABLET_PAD_BUTTON);
+	litest_assert_event_type(ev, LIBINPUT_EVENT_TABLET_PAD_BUTTON);
 	pev = libinput_event_get_tablet_pad_event(ev);
 
 	oldtime = time;
 	time = libinput_event_tablet_pad_get_time(pev);
 	time_usec = libinput_event_tablet_pad_get_time_usec(pev);
 
-	ck_assert(time > oldtime);
-	ck_assert(time != 0);
-	ck_assert(time == time_usec/1000);
+	litest_assert(time > oldtime);
+	litest_assert(time != 0);
+	litest_assert(time == time_usec/1000);
 
 	libinput_event_destroy(ev);
 }
@@ -133,18 +130,18 @@ START_TEST(pad_num_buttons_libwacom)
 	unsigned int nb_lw, nb;
 
 	db = libwacom_database_new();
-	ck_assert_notnull(db);
+	litest_assert_notnull(db);
 
 	wacom = libwacom_new_from_usbid(db,
 					libevdev_get_id_vendor(dev->evdev),
 					libevdev_get_id_product(dev->evdev),
 					NULL);
-	ck_assert_notnull(wacom);
+	litest_assert_notnull(wacom);
 
 	nb_lw = libwacom_get_num_buttons(wacom);
 	nb = libinput_device_tablet_pad_get_num_buttons(device);
 
-	ck_assert_int_eq(nb, nb_lw);
+	litest_assert_int_eq(nb, nb_lw);
 
 	libwacom_destroy(wacom);
 	libwacom_database_destroy(db);
@@ -157,7 +154,7 @@ START_TEST(pad_num_buttons)
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 	unsigned int code;
-	unsigned int nbuttons = 0;
+	int nbuttons = 0;
 
 	for (code = BTN_0; code < KEY_OK; code++) {
 		/* BTN_STYLUS is set for compatibility reasons but not
@@ -169,7 +166,7 @@ START_TEST(pad_num_buttons)
 			nbuttons++;
 	}
 
-	ck_assert_int_eq(libinput_device_tablet_pad_get_num_buttons(device),
+	litest_assert_int_eq(libinput_device_tablet_pad_get_num_buttons(device),
 			 nbuttons);
 }
 END_TEST
@@ -188,7 +185,7 @@ START_TEST(pad_button_intuos)
 	/* Intuos button mapping is sequential up from BTN_0 and continues
 	 * with BTN_A */
 	if (!libevdev_has_event_code(dev->evdev, EV_KEY, BTN_0))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_drain_events(li);
 
@@ -196,7 +193,7 @@ START_TEST(pad_button_intuos)
 		/* Skip over the BTN_MOUSE and BTN_JOYSTICK range */
 		if ((code >= BTN_MOUSE && code < BTN_JOYSTICK) ||
 		    (code >= BTN_DIGI)) {
-			ck_assert(!libevdev_has_event_code(dev->evdev,
+			litest_assert(!libevdev_has_event_code(dev->evdev,
 							   EV_KEY, code));
 			continue;
 		}
@@ -206,7 +203,7 @@ START_TEST(pad_button_intuos)
 
 		litest_button_click(dev, code, 1);
 		litest_button_click(dev, code, 0);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 
 		count++;
 
@@ -229,7 +226,7 @@ START_TEST(pad_button_intuos)
 
 	litest_assert_empty_queue(li);
 
-	ck_assert_int_ge(count, 1);
+	litest_assert_int_ge(count, 1U);
 #endif
 }
 END_TEST
@@ -246,7 +243,7 @@ START_TEST(pad_button_bamboo)
 	unsigned int count = 0;
 
 	if (!libevdev_has_event_code(dev->evdev, EV_KEY, BTN_LEFT))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_drain_events(li);
 
@@ -256,7 +253,7 @@ START_TEST(pad_button_bamboo)
 
 		litest_button_click(dev, code, 1);
 		litest_button_click(dev, code, 0);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 
 		count++;
 
@@ -279,7 +276,7 @@ START_TEST(pad_button_bamboo)
 
 	litest_assert_empty_queue(li);
 
-	ck_assert_int_gt(count, 3);
+	litest_assert_int_gt(count, 3U);
 #endif
 }
 END_TEST
@@ -310,7 +307,7 @@ START_TEST(pad_button_libwacom)
 
 		litest_button_click(dev, code, 1);
 		litest_button_click(dev, code, 0);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 
 		litest_assert_pad_button_event(li,
 					       i,
@@ -330,13 +327,39 @@ START_TEST(pad_button_mode_groups)
 {
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
-	unsigned int code;
 	struct libinput_event *ev;
 	struct libinput_event_tablet_pad *pev;
+	unsigned int expected_mode = 0;
+	int evdev_codes[KEY_OK - BTN_0] = {0};
+#if HAVE_LIBWACOM
+	WacomDeviceDatabase *db = NULL;
+	WacomDevice *wacom = NULL;
+
+	db = libwacom_database_new();
+	litest_assert_notnull(db);
+
+	wacom = libwacom_new_from_usbid(db,
+					libevdev_get_id_vendor(dev->evdev),
+					libevdev_get_id_product(dev->evdev),
+					NULL);
+	if (wacom) {
+		for (size_t i = 0; i < ARRAY_LENGTH(evdev_codes); i++) {
+			evdev_codes[i] = libwacom_get_button_evdev_code(wacom, 'A' + i);
+		}
+	}
+
+	libwacom_destroy(wacom);
+	libwacom_database_destroy(db);
+#else
+	for (size_t i = 0; i < ARRAY_LENGTH(evdev_codes); i++) {
+		evdev_codes[i] = BTN_0 + 1;
+	}
+#endif
 
 	litest_drain_events(li);
 
-	for (code = BTN_0; code < KEY_OK; code++) {
+	for (unsigned int b = 0; b < ARRAY_LENGTH(evdev_codes) && evdev_codes[b] != 0; b++) {
+		unsigned int code = evdev_codes[b];
 		unsigned int mode, index;
 		struct libinput_tablet_pad_mode_group *group;
 
@@ -345,7 +368,7 @@ START_TEST(pad_button_mode_groups)
 
 		litest_button_click(dev, code, 1);
 		litest_button_click(dev, code, 0);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 
 		switch (code) {
 		case BTN_STYLUS:
@@ -356,29 +379,33 @@ START_TEST(pad_button_mode_groups)
 		}
 
 		ev = libinput_get_event(li);
-		ck_assert_int_eq(libinput_event_get_type(ev),
-				 LIBINPUT_EVENT_TABLET_PAD_BUTTON);
+		litest_assert_event_type(ev, LIBINPUT_EVENT_TABLET_PAD_BUTTON);
 		pev = libinput_event_get_tablet_pad_event(ev);
 
-		/* litest virtual devices don't have modes */
-		mode = libinput_event_tablet_pad_get_mode(pev);
-		ck_assert_int_eq(mode, 0);
 		group = libinput_event_tablet_pad_get_mode_group(pev);
+#if HAVE_LIBWACOM
+		if (libinput_tablet_pad_mode_group_button_is_toggle(group, b)) {
+			int num_modes = libinput_tablet_pad_mode_group_get_num_modes(group);
+			expected_mode = (expected_mode + 1) % num_modes;
+		}
+#endif
+		mode = libinput_event_tablet_pad_get_mode(pev);
+		litest_assert_int_eq(mode, expected_mode);
+
 		index = libinput_tablet_pad_mode_group_get_index(group);
-		ck_assert_int_eq(index, 0);
+		litest_assert_int_eq(index, 0U);
 
 		libinput_event_destroy(ev);
 
 		ev = libinput_get_event(li);
-		ck_assert_int_eq(libinput_event_get_type(ev),
-				 LIBINPUT_EVENT_TABLET_PAD_BUTTON);
+		litest_assert_event_type(ev, LIBINPUT_EVENT_TABLET_PAD_BUTTON);
 		pev = libinput_event_get_tablet_pad_event(ev);
 
 		mode = libinput_event_tablet_pad_get_mode(pev);
-		ck_assert_int_eq(mode, 0);
+		litest_assert_int_eq(mode, expected_mode);
 		group = libinput_event_tablet_pad_get_mode_group(pev);
 		index = libinput_tablet_pad_mode_group_get_index(group);
-		ck_assert_int_eq(index, 0);
+		litest_assert_int_eq(index, 0U);
 		libinput_event_destroy(ev);
 	}
 
@@ -393,7 +420,7 @@ START_TEST(pad_has_ring)
 	int nrings;
 
 	nrings = libinput_device_tablet_pad_get_num_rings(device);
-	ck_assert_int_ge(nrings, 1);
+	litest_assert_int_ge(nrings, 1);
 }
 END_TEST
 
@@ -431,7 +458,7 @@ START_TEST(pad_ring)
 	 */
 	for (val = 0; val < 100.0; val += 1) {
 		litest_pad_ring_change(dev, val);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 
 		ev = libinput_get_event(li);
 		if (!ev)
@@ -443,16 +470,16 @@ START_TEST(pad_ring)
 					       LIBINPUT_TABLET_PAD_RING_SOURCE_FINGER);
 
 		degrees = libinput_event_tablet_pad_get_ring_position(pev);
-		ck_assert_double_ge(degrees, 0.0);
-		ck_assert_double_lt(degrees, 360.0);
+		litest_assert_double_ge(degrees, 0.0);
+		litest_assert_double_lt(degrees, 360.0);
 
-		ck_assert_double_eq(degrees, expected);
+		litest_assert_double_eq(degrees, expected);
 
 		libinput_event_destroy(ev);
 		expected = fmod(degrees + step_size, 360);
 	}
 
-	ck_assert_int_eq(nevents, 360/step_size - 1);
+	litest_assert_int_eq(nevents, 360/step_size - 1);
 
 	litest_pad_ring_end(dev);
 }
@@ -471,7 +498,7 @@ START_TEST(pad_ring_finger_up)
 	litest_drain_events(li);
 
 	litest_pad_ring_end(dev);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	ev = libinput_get_event(li);
 	pev = litest_is_pad_ring_event(ev,
@@ -479,7 +506,7 @@ START_TEST(pad_ring_finger_up)
 				       LIBINPUT_TABLET_PAD_RING_SOURCE_FINGER);
 
 	degrees = libinput_event_tablet_pad_get_ring_position(pev);
-	ck_assert_double_eq(degrees, -1.0);
+	litest_assert_double_eq(degrees, -1.0);
 	libinput_event_destroy(ev);
 
 	litest_assert_empty_queue(li);
@@ -497,7 +524,7 @@ START_TEST(pad_has_dial)
 		expected_ndials = 2;
 
 	ndials = libinput_device_tablet_pad_get_num_dials(device);
-	ck_assert_int_eq(ndials, expected_ndials);
+	litest_assert_int_eq(ndials, expected_ndials);
 }
 END_TEST
 
@@ -520,7 +547,7 @@ START_TEST(pad_dial_low_res)
 		if (code == REL_WHEEL)
 			litest_event(dev, EV_REL, REL_WHEEL_HI_RES, direction * 120);
 		litest_event(dev, EV_SYN, SYN_REPORT, 0);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 
 		struct libinput_event *ev = libinput_get_event(li);
 		struct libinput_event_tablet_pad *pev = litest_is_pad_dial_event(ev, 0);
@@ -528,13 +555,13 @@ START_TEST(pad_dial_low_res)
 		double v120 = libinput_event_tablet_pad_get_dial_delta_v120(pev);
 		switch (code) {
 		case REL_WHEEL: /* inverted */
-			ck_assert_double_eq(v120, -120.0 * direction);
+			litest_assert_double_eq(v120, -120.0 * direction);
 			break;
 		case REL_DIAL:
-			ck_assert_double_eq(v120, 120.0 * direction);
+			litest_assert_double_eq(v120, 120.0 * direction);
 			break;
 		default:
-			ck_abort();
+			litest_abort_msg("Invalid dial code");
 		}
 		libinput_event_destroy(ev);
 	}
@@ -549,7 +576,7 @@ START_TEST(pad_dial_hi_res)
 	int accumulated = 0;
 
 	if (!libevdev_has_event_code(dev->evdev, EV_REL, REL_WHEEL_HI_RES))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_drain_events(li);
 
@@ -559,13 +586,13 @@ START_TEST(pad_dial_hi_res)
 		if (accumulated % 120 == 0)
 			litest_event(dev, EV_REL, REL_WHEEL, 1);
 		litest_event(dev, EV_SYN, SYN_REPORT, 0);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 
 		struct libinput_event *ev = libinput_get_event(li);
 		struct libinput_event_tablet_pad *pev = litest_is_pad_dial_event(ev, 0);
 
 		double v120 = libinput_event_tablet_pad_get_dial_delta_v120(pev);
-		ck_assert_double_eq(v120, -increment); /* REL_WHEEL is inverted */
+		litest_assert_double_eq(v120, -increment); /* REL_WHEEL is inverted */
 		libinput_event_destroy(ev);
 	}
 }
@@ -578,7 +605,7 @@ START_TEST(pad_has_strip)
 	int nstrips;
 
 	nstrips = libinput_device_tablet_pad_get_num_strips(device);
-	ck_assert_int_ge(nstrips, 1);
+	litest_assert_int_ge(nstrips, 1);
 }
 END_TEST
 
@@ -601,7 +628,7 @@ START_TEST(pad_strip)
 	 * value. */
 	for (val = 0; val < 100; val += 9.5) {
 		litest_pad_strip_change(dev, val);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 
 		ev = libinput_get_event(li);
 		pev = litest_is_pad_strip_event(ev,
@@ -609,12 +636,12 @@ START_TEST(pad_strip)
 						LIBINPUT_TABLET_PAD_STRIP_SOURCE_FINGER);
 
 		pos = libinput_event_tablet_pad_get_strip_position(pev);
-		ck_assert_double_ge(pos, 0.0);
-		ck_assert_double_lt(pos, 1.0);
+		litest_assert_double_ge(pos, 0.0);
+		litest_assert_double_lt(pos, 1.0);
 
 		/* rounding errors, mostly caused by small physical range */
-		ck_assert_double_ge(pos, expected - 0.02);
-		ck_assert_double_le(pos, expected + 0.02);
+		litest_assert_double_ge(pos, expected - 0.02);
+		litest_assert_double_le(pos, expected + 0.02);
 
 		libinput_event_destroy(ev);
 
@@ -622,14 +649,14 @@ START_TEST(pad_strip)
 	}
 
 	litest_pad_strip_change(dev, 100);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	ev = libinput_get_event(li);
 	pev = litest_is_pad_strip_event(ev,
 					   0,
 					   LIBINPUT_TABLET_PAD_STRIP_SOURCE_FINGER);
 	pos = libinput_event_tablet_pad_get_strip_position(pev);
-	ck_assert_double_eq(pos, 1.0);
+	litest_assert_double_eq(pos, 1.0);
 	libinput_event_destroy(ev);
 
 	litest_pad_strip_end(dev);
@@ -648,7 +675,7 @@ START_TEST(pad_strip_finger_up)
 	litest_drain_events(li);
 
 	litest_pad_strip_end(dev);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	ev = libinput_get_event(li);
 	pev = litest_is_pad_strip_event(ev,
@@ -656,7 +683,7 @@ START_TEST(pad_strip_finger_up)
 					LIBINPUT_TABLET_PAD_STRIP_SOURCE_FINGER);
 
 	pos = libinput_event_tablet_pad_get_strip_position(pev);
-	ck_assert_double_eq(pos, -1.0);
+	litest_assert_double_eq(pos, -1.0);
 	libinput_event_destroy(ev);
 
 	litest_assert_empty_queue(li);
@@ -670,27 +697,27 @@ START_TEST(pad_left_handed_default)
 	struct libinput_device *device = dev->libinput_device;
 	enum libinput_config_status status;
 
-	ck_assert(libinput_device_config_left_handed_is_available(device));
+	litest_assert(libinput_device_config_left_handed_is_available(device));
 
-	ck_assert_int_eq(libinput_device_config_left_handed_get_default(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get_default(device),
 			 0);
-	ck_assert_int_eq(libinput_device_config_left_handed_get(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get(device),
 			 0);
 
 	status = libinput_device_config_left_handed_set(dev->libinput_device, 1);
-	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
+	litest_assert_enum_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
-	ck_assert_int_eq(libinput_device_config_left_handed_get(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get(device),
 			 1);
-	ck_assert_int_eq(libinput_device_config_left_handed_get_default(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get_default(device),
 			 0);
 
 	status = libinput_device_config_left_handed_set(dev->libinput_device, 0);
-	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
+	litest_assert_enum_eq(status, LIBINPUT_CONFIG_STATUS_SUCCESS);
 
-	ck_assert_int_eq(libinput_device_config_left_handed_get(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get(device),
 			 0);
-	ck_assert_int_eq(libinput_device_config_left_handed_get_default(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get_default(device),
 			 0);
 
 #endif
@@ -701,35 +728,35 @@ START_TEST(pad_no_left_handed)
 {
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
-	enum libinput_config_status status;
 
 	/* Without libwacom we default to left-handed being available */
 #if HAVE_LIBWACOM
-	ck_assert(!libinput_device_config_left_handed_is_available(device));
+	litest_assert(!libinput_device_config_left_handed_is_available(device));
 #else
-	ck_assert(libinput_device_config_left_handed_is_available(device));
+	litest_assert(libinput_device_config_left_handed_is_available(device));
 #endif
 
-	ck_assert_int_eq(libinput_device_config_left_handed_get_default(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get_default(device),
 			 0);
-	ck_assert_int_eq(libinput_device_config_left_handed_get(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get(device),
 			 0);
 
 #if HAVE_LIBWACOM
+	enum libinput_config_status status;
 	status = libinput_device_config_left_handed_set(dev->libinput_device, 1);
-	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_UNSUPPORTED);
+	litest_assert_enum_eq(status, LIBINPUT_CONFIG_STATUS_UNSUPPORTED);
 
-	ck_assert_int_eq(libinput_device_config_left_handed_get(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get(device),
 			 0);
-	ck_assert_int_eq(libinput_device_config_left_handed_get_default(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get_default(device),
 			 0);
 
 	status = libinput_device_config_left_handed_set(dev->libinput_device, 0);
-	ck_assert_int_eq(status, LIBINPUT_CONFIG_STATUS_UNSUPPORTED);
+	litest_assert_enum_eq(status, LIBINPUT_CONFIG_STATUS_UNSUPPORTED);
 
-	ck_assert_int_eq(libinput_device_config_left_handed_get(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get(device),
 			 0);
-	ck_assert_int_eq(libinput_device_config_left_handed_get_default(device),
+	litest_assert_int_eq(libinput_device_config_left_handed_get_default(device),
 			 0);
 #endif
 }
@@ -756,7 +783,7 @@ START_TEST(pad_left_handed_ring)
 
 	for (val = 0; val < 100; val += 10) {
 		litest_pad_ring_change(dev, val);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 
 		ev = libinput_get_event(li);
 		pev = litest_is_pad_ring_event(ev,
@@ -764,12 +791,12 @@ START_TEST(pad_left_handed_ring)
 					       LIBINPUT_TABLET_PAD_RING_SOURCE_FINGER);
 
 		degrees = libinput_event_tablet_pad_get_ring_position(pev);
-		ck_assert_double_ge(degrees, 0.0);
-		ck_assert_double_lt(degrees, 360.0);
+		litest_assert_double_ge(degrees, 0.0);
+		litest_assert_double_lt(degrees, 360.0);
 
 		/* rounding errors, mostly caused by small physical range */
-		ck_assert_double_ge(degrees, expected - 2);
-		ck_assert_double_le(degrees, expected + 2);
+		litest_assert_double_ge(degrees, expected - 2);
+		litest_assert_double_le(degrees, expected + 2);
 
 		libinput_event_destroy(ev);
 
@@ -781,28 +808,55 @@ START_TEST(pad_left_handed_ring)
 }
 END_TEST
 
+static bool
+pad_has_groups(struct litest_device *dev)
+{
+	bool rc = false;
+#if HAVE_LIBWACOM
+	WacomDeviceDatabase *db = NULL;
+	WacomDevice *wacom = NULL;
+
+	db = libwacom_database_new();
+	litest_assert_notnull(db);
+
+	wacom = libwacom_new_from_usbid(db,
+					libevdev_get_id_vendor(dev->evdev),
+					libevdev_get_id_product(dev->evdev),
+					NULL);
+	if (wacom &&
+	    (libwacom_get_ring_num_modes(wacom) != 0 ||
+	    libwacom_get_ring2_num_modes(wacom) != 0 ||
+	    libwacom_get_strips_num_modes(wacom) != 0))
+		rc = true;
+
+	libwacom_destroy(wacom);
+	libwacom_database_destroy(db);
+#endif
+	return rc;
+}
+
 START_TEST(pad_mode_groups)
 {
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 	struct libinput_tablet_pad_mode_group *group;
 	int ngroups;
-	int i;
+	unsigned int i;
 
 	ngroups = libinput_device_tablet_pad_get_num_mode_groups(device);
-	ck_assert_int_eq(ngroups, 1);
+	litest_assert_int_ge(ngroups, 1);
 
-	for (i = 0; i < ngroups; i++) {
+	for (i = 0; i < (unsigned int)ngroups; i++) {
 		group = libinput_device_tablet_pad_get_mode_group(device, i);
-		ck_assert_notnull(group);
-		ck_assert_int_eq(libinput_tablet_pad_mode_group_get_index(group),
+		litest_assert_notnull(group);
+		litest_assert_int_eq(libinput_tablet_pad_mode_group_get_index(group),
 				 i);
 	}
 
 	group = libinput_device_tablet_pad_get_mode_group(device, ngroups);
-	ck_assert(group == NULL);
+	litest_assert(group == NULL);
 	group = libinput_device_tablet_pad_get_mode_group(device, ngroups + 1);
-	ck_assert(group == NULL);
+	litest_assert(group == NULL);
 }
 END_TEST
 
@@ -815,14 +869,14 @@ START_TEST(pad_mode_groups_userdata)
 	void *userdata = &rc;
 
 	group = libinput_device_tablet_pad_get_mode_group(device, 0);
-	ck_assert(libinput_tablet_pad_mode_group_get_user_data(group) ==
+	litest_assert(libinput_tablet_pad_mode_group_get_user_data(group) ==
 		  NULL);
 	libinput_tablet_pad_mode_group_set_user_data(group, userdata);
-	ck_assert(libinput_tablet_pad_mode_group_get_user_data(group) ==
+	litest_assert(libinput_tablet_pad_mode_group_get_user_data(group) ==
 		  &rc);
 
 	libinput_tablet_pad_mode_group_set_user_data(group, NULL);
-	ck_assert(libinput_tablet_pad_mode_group_get_user_data(group) ==
+	litest_assert(libinput_tablet_pad_mode_group_get_user_data(group) ==
 		  NULL);
 }
 END_TEST
@@ -835,12 +889,12 @@ START_TEST(pad_mode_groups_ref)
 
 	group = libinput_device_tablet_pad_get_mode_group(device, 0);
 	g = libinput_tablet_pad_mode_group_ref(group);
-	ck_assert_ptr_eq(g, group);
+	litest_assert_ptr_eq(g, group);
 
 	/* We don't expect this to be freed. Any leaks should be caught by
 	 * valgrind. */
 	g = libinput_tablet_pad_mode_group_unref(group);
-	ck_assert_ptr_eq(g, group);
+	litest_assert_ptr_eq(g, group);
 }
 END_TEST
 
@@ -852,16 +906,19 @@ START_TEST(pad_mode_group_mode)
 	int ngroups;
 	unsigned int nmodes, mode;
 
+	if (pad_has_groups(dev))
+		return LITEST_NOT_APPLICABLE;
+
 	ngroups = libinput_device_tablet_pad_get_num_mode_groups(device);
-	ck_assert_int_ge(ngroups, 1);
+	litest_assert_int_ge(ngroups, 1);
 
 	group = libinput_device_tablet_pad_get_mode_group(device, 0);
 
 	nmodes = libinput_tablet_pad_mode_group_get_num_modes(group);
-	ck_assert_int_eq(nmodes, 1);
+	litest_assert_int_eq(nmodes, 1U);
 
 	mode = libinput_tablet_pad_mode_group_get_mode(group);
-	ck_assert_int_lt(mode, nmodes);
+	litest_assert_int_lt(mode, nmodes);
 }
 END_TEST
 
@@ -874,7 +931,7 @@ START_TEST(pad_mode_group_has)
 	int i, b, r, s;
 
 	ngroups = libinput_device_tablet_pad_get_num_mode_groups(device);
-	ck_assert_int_ge(ngroups, 1);
+	litest_assert_int_ge(ngroups, 1);
 
 	nbuttons = libinput_device_tablet_pad_get_num_buttons(device);
 	nrings = libinput_device_tablet_pad_get_num_rings(device);
@@ -887,11 +944,11 @@ START_TEST(pad_mode_group_has)
 									  i);
 			if (libinput_tablet_pad_mode_group_has_button(group,
 								      b)) {
-				ck_assert(!found);
+				litest_assert(!found);
 				found = true;
 			}
 		}
-		ck_assert(found);
+		litest_assert(found);
 	}
 
 	for (s = 0; s < nstrips; s++) {
@@ -901,11 +958,11 @@ START_TEST(pad_mode_group_has)
 									  i);
 			if (libinput_tablet_pad_mode_group_has_strip(group,
 								     s)) {
-				ck_assert(!found);
+				litest_assert(!found);
 				found = true;
 			}
 		}
-		ck_assert(found);
+		litest_assert(found);
 	}
 
 	for (r = 0; r < nrings; r++) {
@@ -915,11 +972,11 @@ START_TEST(pad_mode_group_has)
 									  i);
 			if (libinput_tablet_pad_mode_group_has_ring(group,
 								    r)) {
-				ck_assert(!found);
+				litest_assert(!found);
 				found = true;
 			}
 		}
-		ck_assert(found);
+		litest_assert(found);
 	}
 }
 END_TEST
@@ -934,7 +991,7 @@ START_TEST(pad_mode_group_has_invalid)
 	int rc;
 
 	ngroups = libinput_device_tablet_pad_get_num_mode_groups(device);
-	ck_assert_int_ge(ngroups, 1);
+	litest_assert_int_ge(ngroups, 1);
 
 	nbuttons = libinput_device_tablet_pad_get_num_buttons(device);
 	nrings = libinput_device_tablet_pad_get_num_rings(device);
@@ -944,64 +1001,69 @@ START_TEST(pad_mode_group_has_invalid)
 		group = libinput_device_tablet_pad_get_mode_group(device, i);
 		rc = libinput_tablet_pad_mode_group_has_button(group,
 							       nbuttons);
-		ck_assert_int_eq(rc, 0);
+		litest_assert_int_eq(rc, 0);
 		rc = libinput_tablet_pad_mode_group_has_button(group,
 							       nbuttons + 1);
-		ck_assert_int_eq(rc, 0);
+		litest_assert_int_eq(rc, 0);
 		rc = libinput_tablet_pad_mode_group_has_button(group,
 							       0x1000000);
-		ck_assert_int_eq(rc, 0);
+		litest_assert_int_eq(rc, 0);
 	}
 
 	for (i = 0; i < ngroups; i++) {
 		group = libinput_device_tablet_pad_get_mode_group(device, i);
 		rc = libinput_tablet_pad_mode_group_has_strip(group,
 							      nstrips);
-		ck_assert_int_eq(rc, 0);
+		litest_assert_int_eq(rc, 0);
 		rc = libinput_tablet_pad_mode_group_has_strip(group,
 							       nstrips + 1);
-		ck_assert_int_eq(rc, 0);
+		litest_assert_int_eq(rc, 0);
 		rc = libinput_tablet_pad_mode_group_has_strip(group,
 							       0x1000000);
-		ck_assert_int_eq(rc, 0);
+		litest_assert_int_eq(rc, 0);
 	}
 
 	for (i = 0; i < ngroups; i++) {
 		group = libinput_device_tablet_pad_get_mode_group(device, i);
 		rc = libinput_tablet_pad_mode_group_has_ring(group,
 							     nrings);
-		ck_assert_int_eq(rc, 0);
+		litest_assert_int_eq(rc, 0);
 		rc = libinput_tablet_pad_mode_group_has_ring(group,
 							     nrings + 1);
-		ck_assert_int_eq(rc, 0);
+		litest_assert_int_eq(rc, 0);
 		rc = libinput_tablet_pad_mode_group_has_ring(group,
 							     0x1000000);
-		ck_assert_int_eq(rc, 0);
+		litest_assert_int_eq(rc, 0);
 	}
 }
 END_TEST
 
 START_TEST(pad_mode_group_has_no_toggle)
 {
+#if HAVE_LIBWACOM
 	struct litest_device *dev = litest_current_device();
 	struct libinput_device *device = dev->libinput_device;
 	struct libinput_tablet_pad_mode_group* group;
 	int ngroups, nbuttons;
 	int i, b;
 
+	if (pad_has_groups(dev))
+		return LITEST_NOT_APPLICABLE;
+
 	ngroups = libinput_device_tablet_pad_get_num_mode_groups(device);
-	ck_assert_int_ge(ngroups, 1);
+	litest_assert_int_eq(ngroups, 1);
 
 	/* Button must not be toggle buttons */
 	nbuttons = libinput_device_tablet_pad_get_num_buttons(device);
 	for (i = 0; i < ngroups; i++) {
 		group = libinput_device_tablet_pad_get_mode_group(device, i);
 		for (b = 0; b < nbuttons; b++) {
-			ck_assert(!libinput_tablet_pad_mode_group_button_is_toggle(
+			litest_assert(!libinput_tablet_pad_mode_group_button_is_toggle(
 								    group,
 								    b));
 		}
 	}
+#endif
 }
 END_TEST
 
@@ -1038,40 +1100,40 @@ START_TEST(pad_keys)
 	unsigned int key;
 
 	if (!pad_has_keys(dev))
-		return;
+		return LITEST_NOT_APPLICABLE;
 
 	litest_drain_events(li);
 
 	key = KEY_BUTTONCONFIG;
 	pad_key_down(dev, key);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_PRESSED);
 
 	pad_key_up(dev, key);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_RELEASED);
 
 	key = KEY_ONSCREEN_KEYBOARD;
 	pad_key_down(dev, key);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_PRESSED);
 
 	pad_key_up(dev, key);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_RELEASED);
 
 	key = KEY_CONTROLPANEL;
 	pad_key_down(dev, key);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_PRESSED);
 
 	pad_key_up(dev, key);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	litest_assert_pad_key_event(li, key, LIBINPUT_KEY_STATE_RELEASED);
 }
 END_TEST
 
-TEST_COLLECTION(tablet_pad)
+TEST_COLLECTION(pad)
 {
 	litest_add(pad_cap, LITEST_TABLET_PAD, LITEST_ANY);
 	litest_add(pad_no_cap, LITEST_ANY, LITEST_TABLET_PAD);
