@@ -23,7 +23,6 @@
 
 #include <config.h>
 
-#include <check.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <libinput.h>
@@ -92,13 +91,13 @@ START_TEST(path_create_NULL)
 	counter.close_func_count = 0;
 
 	li = libinput_path_create_context(NULL, NULL);
-	ck_assert(li == NULL);
+	litest_assert(li == NULL);
 	li = libinput_path_create_context(&counting_interface, &counter);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 	libinput_unref(li);
 
-	ck_assert_int_eq(counter.open_func_count, 0);
-	ck_assert_int_eq(counter.close_func_count, 0);
+	litest_assert_int_eq(counter.open_func_count, 0);
+	litest_assert_int_eq(counter.close_func_count, 0);
 }
 END_TEST
 
@@ -113,19 +112,19 @@ START_TEST(path_create_invalid)
 	counter.close_func_count = 0;
 
 	li = libinput_path_create_context(&counting_interface, &counter);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	litest_disable_log_handler(li);
 
 	device = libinput_path_add_device(li, path);
-	ck_assert(device == NULL);
+	litest_assert(device == NULL);
 
-	ck_assert_int_eq(counter.open_func_count, 0);
-	ck_assert_int_eq(counter.close_func_count, 0);
+	litest_assert_int_eq(counter.open_func_count, 0);
+	litest_assert_int_eq(counter.close_func_count, 0);
 
 	litest_restore_log_handler(li);
 	libinput_unref(li);
-	ck_assert_int_eq(counter.close_func_count, 0);
+	litest_assert_int_eq(counter.close_func_count, 0);
 }
 END_TEST
 
@@ -140,19 +139,19 @@ START_TEST(path_create_invalid_kerneldev)
 	counter.close_func_count = 0;
 
 	li = libinput_path_create_context(&counting_interface, &counter);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	litest_disable_log_handler(li);
 
 	device = libinput_path_add_device(li, path);
-	ck_assert(device == NULL);
+	litest_assert(device == NULL);
 
-	ck_assert_int_eq(counter.open_func_count, 1);
-	ck_assert_int_eq(counter.close_func_count, 1);
+	litest_assert_int_eq(counter.open_func_count, 1);
+	litest_assert_int_eq(counter.close_func_count, 1);
 
 	litest_restore_log_handler(li);
 	libinput_unref(li);
-	ck_assert_int_eq(counter.close_func_count, 1);
+	litest_assert_int_eq(counter.close_func_count, 1);
 }
 END_TEST
 
@@ -166,7 +165,7 @@ START_TEST(path_create_invalid_file)
 
 	umask(002);
 	fd = mkstemp(path);
-	ck_assert_int_ge(fd, 0);
+	litest_assert_int_ge(fd, 0);
 	close(fd);
 
 	counter.open_func_count = 0;
@@ -177,16 +176,16 @@ START_TEST(path_create_invalid_file)
 
 	litest_disable_log_handler(li);
 
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 	device = libinput_path_add_device(li, path);
-	ck_assert(device == NULL);
+	litest_assert(device == NULL);
 
-	ck_assert_int_eq(counter.open_func_count, 0);
-	ck_assert_int_eq(counter.close_func_count, 0);
+	litest_assert_int_eq(counter.open_func_count, 0);
+	litest_assert_int_eq(counter.close_func_count, 0);
 
 	litest_restore_log_handler(li);
 	libinput_unref(li);
-	ck_assert_int_eq(counter.close_func_count, 0);
+	litest_assert_int_eq(counter.close_func_count, 0);
 }
 END_TEST
 
@@ -206,16 +205,16 @@ START_TEST(path_create_pathmax_file)
 	li = libinput_path_create_context(&counting_interface, &counter);
 
 	litest_set_log_handler_bug(li);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 	device = libinput_path_add_device(li, path);
-	ck_assert(device == NULL);
+	litest_assert(device == NULL);
 
-	ck_assert_int_eq(counter.open_func_count, 0);
-	ck_assert_int_eq(counter.close_func_count, 0);
+	litest_assert_int_eq(counter.open_func_count, 0);
+	litest_assert_int_eq(counter.close_func_count, 0);
 
 	litest_restore_log_handler(li);
 	libinput_unref(li);
-	ck_assert_int_eq(counter.close_func_count, 0);
+	litest_assert_int_eq(counter.close_func_count, 0);
 
 	free(path);
 }
@@ -240,21 +239,21 @@ START_TEST(path_create_destroy)
 					     -1);
 
 	li = libinput_path_create_context(&counting_interface, &counter);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	litest_disable_log_handler(li);
 
-	ck_assert(libinput_get_user_data(li) == &counter);
+	litest_assert(libinput_get_user_data(li) == &counter);
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
-	ck_assert_int_eq(counter.open_func_count, 1);
+	litest_assert_int_eq(counter.open_func_count, 1);
 
 	libevdev_uinput_destroy(uinput);
 	libinput_unref(li);
-	ck_assert_int_eq(counter.close_func_count, 1);
+	litest_assert_int_eq(counter.close_func_count, 1);
 }
 END_TEST
 
@@ -265,11 +264,11 @@ START_TEST(path_force_destroy)
 	struct libinput_device *device;
 
 	li = libinput_path_create_context(&simple_interface, NULL);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 	libinput_ref(li);
 	device = libinput_path_add_device(li,
 				  libevdev_uinput_get_devnode(dev->uinput));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
 	while (libinput_unref(li) != NULL)
 		;
@@ -282,10 +281,10 @@ START_TEST(path_set_user_data)
 	int data1, data2;
 
 	li = libinput_path_create_context(&simple_interface, &data1);
-	ck_assert_notnull(li);
-	ck_assert(libinput_get_user_data(li) == &data1);
+	litest_assert_notnull(li);
+	litest_assert(libinput_get_user_data(li) == &data1);
 	libinput_set_user_data(li, &data2);
-	ck_assert(libinput_get_user_data(li) == &data2);
+	litest_assert(libinput_get_user_data(li) == &data2);
 
 	libinput_unref(li);
 }
@@ -299,22 +298,20 @@ START_TEST(path_added_seat)
 	struct libinput_device *device;
 	struct libinput_seat *seat;
 	const char *seat_name;
-	enum libinput_event_type type;
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
+	litest_assert_notnull(event);
 
-	type = libinput_event_get_type(event);
-	ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+	litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 
 	device = libinput_event_get_device(event);
 	seat = libinput_device_get_seat(device);
-	ck_assert_notnull(seat);
+	litest_assert_notnull(seat);
 
 	seat_name = libinput_seat_get_logical_name(seat);
-	ck_assert_str_eq(seat_name, "default");
+	litest_assert_str_eq(seat_name, "default");
 
 	libinput_event_destroy(event);
 }
@@ -331,11 +328,10 @@ START_TEST(path_seat_change)
 	const char *seat2_name = "new seat";
 	int rc;
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
-	ck_assert_int_eq(libinput_event_get_type(event),
-			 LIBINPUT_EVENT_DEVICE_ADDED);
+	litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 
 	device = libinput_event_get_device(event);
 	libinput_device_ref(device);
@@ -350,32 +346,30 @@ START_TEST(path_seat_change)
 
 	rc = libinput_device_set_seat_logical_name(device,
 						   seat2_name);
-	ck_assert_int_eq(rc, 0);
+	litest_assert_int_eq(rc, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
+	litest_assert_notnull(event);
 
-	ck_assert_int_eq(libinput_event_get_type(event),
-			 LIBINPUT_EVENT_DEVICE_REMOVED);
+	litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_REMOVED);
 
-	ck_assert(libinput_event_get_device(event) == device);
+	litest_assert(libinput_event_get_device(event) == device);
 	libinput_event_destroy(event);
 
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
-	ck_assert_int_eq(libinput_event_get_type(event),
-			 LIBINPUT_EVENT_DEVICE_ADDED);
-	ck_assert(libinput_event_get_device(event) != device);
+	litest_assert_notnull(event);
+	litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
+	litest_assert(libinput_event_get_device(event) != device);
 	libinput_device_unref(device);
 
 	device = libinput_event_get_device(event);
 	seat2 = libinput_device_get_seat(device);
 
-	ck_assert_str_ne(libinput_seat_get_logical_name(seat2),
+	litest_assert_str_ne(libinput_seat_get_logical_name(seat2),
 			 seat1_name);
-	ck_assert_str_eq(libinput_seat_get_logical_name(seat2),
+	litest_assert_str_eq(libinput_seat_get_logical_name(seat2),
 			 seat2_name);
 	libinput_event_destroy(event);
 
@@ -394,16 +388,14 @@ START_TEST(path_added_device)
 	struct libinput *li = dev->libinput;
 	struct libinput_event *event;
 	struct libinput_device *device;
-	enum libinput_event_type type;
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
-	type = libinput_event_get_type(event);
-	ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+	litest_assert_notnull(event);
+	litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 	device = libinput_event_get_device(event);
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
 	libinput_event_destroy(event);
 }
@@ -416,16 +408,14 @@ START_TEST(path_add_device)
 	struct libinput_event *event;
 	struct libinput_device *device;
 	char *sysname1 = NULL, *sysname2 = NULL;
-	enum libinput_event_type type;
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
-	type = libinput_event_get_type(event);
-	ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+	litest_assert_notnull(event);
+	litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 	device = libinput_event_get_device(event);
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 	sysname1 = safe_strdup(libinput_device_get_sysname(device));
 	libinput_event_destroy(event);
 
@@ -433,20 +423,19 @@ START_TEST(path_add_device)
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(dev->uinput));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
-	type = libinput_event_get_type(event);
-	ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+	litest_assert_notnull(event);
+	litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 	device = libinput_event_get_device(event);
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 	sysname2 = safe_strdup(libinput_device_get_sysname(device));
 	libinput_event_destroy(event);
 
-	ck_assert_str_eq(sysname1, sysname2);
+	litest_assert_str_eq(sysname1, sysname2);
 
 	free(sysname1);
 	free(sysname2);
@@ -463,9 +452,9 @@ START_TEST(path_add_invalid_path)
 	litest_disable_log_handler(li);
 	device = libinput_path_add_device(li, "/tmp/");
 	litest_restore_log_handler(li);
-	ck_assert(device == NULL);
+	litest_assert(device == NULL);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	litest_assert_empty_queue(li);
 
@@ -479,22 +468,20 @@ START_TEST(path_device_sysname)
 	struct libinput_event *ev;
 	struct libinput_device *device;
 	const char *sysname;
-	enum libinput_event_type type;
 
-	libinput_dispatch(dev->libinput);
+	litest_dispatch(dev->libinput);
 
 	ev = libinput_get_event(dev->libinput);
-	ck_assert_notnull(ev);
-	type = libinput_event_get_type(ev);
-	ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+	litest_assert_notnull(ev);
+	litest_assert_event_type(ev, LIBINPUT_EVENT_DEVICE_ADDED);
 	device = libinput_event_get_device(ev);
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 	sysname = libinput_device_get_sysname(device);
 
-	ck_assert_notnull(sysname);
-	ck_assert_int_gt(strlen(sysname), 1);
-	ck_assert(strchr(sysname, '/') == NULL);
-	ck_assert(strneq(sysname, "event", 5));
+	litest_assert_notnull(sysname);
+	litest_assert_int_gt(strlen(sysname), 1U);
+	litest_assert(strchr(sysname, '/') == NULL);
+	litest_assert(strneq(sysname, "event", 5));
 
 	libinput_event_destroy(ev);
 }
@@ -510,11 +497,11 @@ START_TEST(path_remove_device)
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(dev->uinput));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 	litest_drain_events(li);
 
 	libinput_path_remove_device(device);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	while ((event = libinput_get_event(li))) {
 		enum libinput_event_type type;
@@ -526,7 +513,7 @@ START_TEST(path_remove_device)
 		libinput_event_destroy(event);
 	}
 
-	ck_assert_int_eq(remove_event, 1);
+	litest_assert_int_eq(remove_event, 1);
 }
 END_TEST
 
@@ -540,12 +527,12 @@ START_TEST(path_double_remove_device)
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(dev->uinput));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 	litest_drain_events(li);
 
 	libinput_path_remove_device(device);
 	libinput_path_remove_device(device);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	while ((event = libinput_get_event(li))) {
 		enum libinput_event_type type;
@@ -557,7 +544,7 @@ START_TEST(path_double_remove_device)
 		libinput_event_destroy(event);
 	}
 
-	ck_assert_int_eq(remove_event, 1);
+	litest_assert_int_eq(remove_event, 1);
 }
 END_TEST
 
@@ -577,11 +564,11 @@ START_TEST(path_suspend)
 					     -1);
 
 	li = libinput_path_create_context(&simple_interface, userdata);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
 	libinput_suspend(li);
 	libinput_resume(li);
@@ -607,11 +594,11 @@ START_TEST(path_double_suspend)
 					     -1);
 
 	li = libinput_path_create_context(&simple_interface, userdata);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
 	libinput_suspend(li);
 	libinput_suspend(li);
@@ -638,11 +625,11 @@ START_TEST(path_double_resume)
 					     -1);
 
 	li = libinput_path_create_context(&simple_interface, userdata);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
 	libinput_suspend(li);
 	libinput_resume(li);
@@ -677,53 +664,47 @@ START_TEST(path_add_device_suspend_resume)
 					      -1);
 
 	li = libinput_path_create_context(&simple_interface, userdata);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput1));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 	libinput_path_add_device(li, libevdev_uinput_get_devnode(uinput2));
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	nevents = 0;
 	while ((event = libinput_get_event(li))) {
-		enum libinput_event_type type;
-		type = libinput_event_get_type(event);
-		ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+		litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 		libinput_event_destroy(event);
 		nevents++;
 	}
 
-	ck_assert_int_eq(nevents, 2);
+	litest_assert_int_eq(nevents, 2);
 
 	libinput_suspend(li);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	nevents = 0;
 	while ((event = libinput_get_event(li))) {
-		enum libinput_event_type type;
-		type = libinput_event_get_type(event);
-		ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_REMOVED);
+		litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_REMOVED);
 		libinput_event_destroy(event);
 		nevents++;
 	}
 
-	ck_assert_int_eq(nevents, 2);
+	litest_assert_int_eq(nevents, 2);
 
 	libinput_resume(li);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	nevents = 0;
 	while ((event = libinput_get_event(li))) {
-		enum libinput_event_type type;
-		type = libinput_event_get_type(event);
-		ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+		litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 		libinput_event_destroy(event);
 		nevents++;
 	}
 
-	ck_assert_int_eq(nevents, 2);
+	litest_assert_int_eq(nevents, 2);
 
 	libevdev_uinput_destroy(uinput1);
 	libevdev_uinput_destroy(uinput2);
@@ -755,48 +736,44 @@ START_TEST(path_add_device_suspend_resume_fail)
 					      -1);
 
 	li = libinput_path_create_context(&simple_interface, userdata);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput1));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput2));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	nevents = 0;
 	while ((event = libinput_get_event(li))) {
-		enum libinput_event_type type;
-		type = libinput_event_get_type(event);
-		ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+		litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 		libinput_event_destroy(event);
 		nevents++;
 	}
 
-	ck_assert_int_eq(nevents, 2);
+	litest_assert_int_eq(nevents, 2);
 
 	libinput_suspend(li);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	nevents = 0;
 	while ((event = libinput_get_event(li))) {
-		enum libinput_event_type type;
-		type = libinput_event_get_type(event);
-		ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_REMOVED);
+		litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_REMOVED);
 		libinput_event_destroy(event);
 		nevents++;
 	}
 
-	ck_assert_int_eq(nevents, 2);
+	litest_assert_int_eq(nevents, 2);
 
 	/* now drop one of the devices */
 	libevdev_uinput_destroy(uinput1);
 	rc = libinput_resume(li);
-	ck_assert_int_eq(rc, -1);
+	litest_assert_int_eq(rc, -1);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	nevents = 0;
 	while ((event = libinput_get_event(li))) {
@@ -806,12 +783,12 @@ START_TEST(path_add_device_suspend_resume_fail)
 		 * causing a removed event for the first one */
 		if (type != LIBINPUT_EVENT_DEVICE_ADDED &&
 		    type != LIBINPUT_EVENT_DEVICE_REMOVED)
-			ck_abort();
+			litest_abort_msg("Unexpected event type");
 		libinput_event_destroy(event);
 		nevents++;
 	}
 
-	ck_assert_int_eq(nevents, 2);
+	litest_assert_int_eq(nevents, 2);
 
 	libevdev_uinput_destroy(uinput2);
 	libinput_unref(li);
@@ -842,41 +819,37 @@ START_TEST(path_add_device_suspend_resume_remove_device)
 					      -1);
 
 	li = libinput_path_create_context(&simple_interface, userdata);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput1));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput2));
 
 	libinput_device_ref(device);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	nevents = 0;
 	while ((event = libinput_get_event(li))) {
-		enum libinput_event_type type;
-		type = libinput_event_get_type(event);
-		ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+		litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 		libinput_event_destroy(event);
 		nevents++;
 	}
 
-	ck_assert_int_eq(nevents, 2);
+	litest_assert_int_eq(nevents, 2);
 
 	libinput_suspend(li);
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	nevents = 0;
 	while ((event = libinput_get_event(li))) {
-		enum libinput_event_type type;
-		type = libinput_event_get_type(event);
-		ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_REMOVED);
+		litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_REMOVED);
 		libinput_event_destroy(event);
 		nevents++;
 	}
 
-	ck_assert_int_eq(nevents, 2);
+	litest_assert_int_eq(nevents, 2);
 
 	/* now drop and remove one of the devices */
 	libevdev_uinput_destroy(uinput2);
@@ -884,20 +857,18 @@ START_TEST(path_add_device_suspend_resume_remove_device)
 	libinput_device_unref(device);
 
 	rc = libinput_resume(li);
-	ck_assert_int_eq(rc, 0);
+	litest_assert_int_eq(rc, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	nevents = 0;
 	while ((event = libinput_get_event(li))) {
-		enum libinput_event_type type;
-		type = libinput_event_get_type(event);
-		ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+		litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_ADDED);
 		libinput_event_destroy(event);
 		nevents++;
 	}
 
-	ck_assert_int_eq(nevents, 1);
+	litest_assert_int_eq(nevents, 1);
 
 	libevdev_uinput_destroy(uinput1);
 	libinput_unref(li);
@@ -919,20 +890,20 @@ START_TEST(path_device_gone)
 					     -1);
 
 	li = libinput_path_create_context(&simple_interface, NULL);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
 	litest_drain_events(li);
 
 	libevdev_uinput_destroy(uinput);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
+	litest_assert_notnull(event);
 	litest_assert_event_type(event, LIBINPUT_EVENT_DEVICE_REMOVED);
 	libinput_event_destroy(event);
 
@@ -953,7 +924,6 @@ START_TEST(path_seat_recycle)
 	int data = 0;
 	int found = 0;
 	void *user_data;
-	enum libinput_event_type type;
 
 	uinput = litest_create_uinput_device("test device", NULL,
 					     EV_KEY, BTN_LEFT,
@@ -963,25 +933,24 @@ START_TEST(path_seat_recycle)
 					     -1);
 
 	li = libinput_path_create_context(&simple_interface, userdata);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	device = libinput_path_add_device(li,
 					  libevdev_uinput_get_devnode(uinput));
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	ev = libinput_get_event(li);
-	ck_assert_notnull(ev);
-	type = libinput_event_get_type(ev);
-	ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+	litest_assert_notnull(ev);
+	litest_assert_event_type(ev, LIBINPUT_EVENT_DEVICE_ADDED);
 	device = libinput_event_get_device(ev);
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 	saved_seat = libinput_device_get_seat(device);
 	libinput_seat_set_user_data(saved_seat, &data);
 	libinput_seat_ref(saved_seat);
 	libinput_event_destroy(ev);
-	ck_assert_notnull(saved_seat);
+	litest_assert_notnull(saved_seat);
 
 	litest_assert_empty_queue(li);
 
@@ -991,23 +960,22 @@ START_TEST(path_seat_recycle)
 
 	libinput_resume(li);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	ev = libinput_get_event(li);
-	ck_assert_notnull(ev);
-	type = libinput_event_get_type(ev);
-	ck_assert_int_eq(type, LIBINPUT_EVENT_DEVICE_ADDED);
+	litest_assert_notnull(ev);
+	litest_assert_event_type(ev, LIBINPUT_EVENT_DEVICE_ADDED);
 	device = libinput_event_get_device(ev);
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
 	seat = libinput_device_get_seat(device);
 	user_data = libinput_seat_get_user_data(seat);
 	if (user_data == &data) {
 		found = 1;
-		ck_assert(seat == saved_seat);
+		litest_assert(seat == saved_seat);
 	}
 
 	libinput_event_destroy(ev);
-	ck_assert(found == 1);
+	litest_assert(found == 1);
 
 	libinput_unref(li);
 
@@ -1023,7 +991,7 @@ START_TEST(path_udev_assign_seat)
 
 	litest_set_log_handler_bug(li);
 	rc = libinput_udev_assign_seat(li, "foo");
-	ck_assert_int_eq(rc, -1);
+	litest_assert_int_eq(rc, -1);
 	litest_restore_log_handler(li);
 }
 END_TEST
@@ -1037,11 +1005,11 @@ START_TEST(path_ignore_device)
 
 	dev = litest_create(LITEST_IGNORED_MOUSE, NULL, NULL, NULL, NULL);
 	path = libevdev_uinput_get_devnode(dev->uinput);
-	ck_assert_notnull(path);
+	litest_assert_notnull(path);
 
 	li = litest_create_context();
 	device = libinput_path_add_device(li, path);
-	ck_assert(device == NULL);
+	litest_assert(device == NULL);
 
 	litest_destroy_context(li);
 	litest_delete_device(dev);
