@@ -23,7 +23,6 @@
 
 #include <config.h>
 
-#include <check.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <libinput.h>
@@ -57,17 +56,17 @@ START_TEST(udev_create_NULL)
 	udev = udev_new();
 
 	li = libinput_udev_create_context(NULL, NULL, NULL);
-	ck_assert(li == NULL);
+	litest_assert(li == NULL);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, NULL);
-	ck_assert(li == NULL);
+	litest_assert(li == NULL);
 
 	li = libinput_udev_create_context(NULL, NULL, udev);
-	ck_assert(li == NULL);
+	litest_assert(li == NULL);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, NULL), -1);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, NULL), -1);
 
 	libinput_unref(li);
 	udev_unref(udev);
@@ -82,19 +81,19 @@ START_TEST(udev_create_seat0)
 	int fd;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
 
 	fd = libinput_get_fd(li);
-	ck_assert_int_ge(fd, 0);
+	litest_assert_int_ge(fd, 0);
 
 	/* expect at least one event */
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
+	litest_assert_notnull(event);
 
 	libinput_event_destroy(event);
 	libinput_unref(li);
@@ -110,19 +109,19 @@ START_TEST(udev_create_empty_seat)
 	int fd;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	/* expect a libinput reference, but no events */
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seatdoesntexist"), 0);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seatdoesntexist"), 0);
 
 	fd = libinput_get_fd(li);
-	ck_assert_int_ge(fd, 0);
+	litest_assert_int_ge(fd, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	event = libinput_get_event(li);
-	ck_assert(event == NULL);
+	litest_assert(event == NULL);
 
 	libinput_event_destroy(event);
 	libinput_unref(li);
@@ -140,13 +139,13 @@ START_TEST(udev_create_seat_too_long)
 	seatname[sizeof(seatname) - 1] = '\0';
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 	litest_set_log_handler_bug(li);
 
-	ck_assert_int_eq(libinput_udev_assign_seat(li, seatname), -1);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, seatname), -1);
 
 	litest_assert_empty_queue(li);
 
@@ -162,13 +161,13 @@ START_TEST(udev_set_user_data)
 	int data1, data2;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, &data1, udev);
-	ck_assert_notnull(li);
-	ck_assert(libinput_get_user_data(li) == &data1);
+	litest_assert_notnull(li);
+	litest_assert(libinput_get_user_data(li) == &data1);
 	libinput_set_user_data(li, &data2);
-	ck_assert(libinput_get_user_data(li) == &data2);
+	litest_assert(libinput_get_user_data(li) == &data2);
 
 	libinput_unref(li);
 	udev_unref(udev);
@@ -186,12 +185,12 @@ START_TEST(udev_added_seat_default)
 	struct litest_device *dev;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
-	libinput_dispatch(li);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_dispatch(li);
 
 	/* Drop any events from other devices */
 	litest_drain_events(li);
@@ -200,14 +199,14 @@ START_TEST(udev_added_seat_default)
 	 * logical seat. This test may fail if there is a local rule changing
 	 * that, but it'll be fine for the 99% case. */
 	dev = litest_create(LITEST_MOUSE, NULL, NULL, NULL, NULL);
-	litest_wait_for_event_of_type(li, LIBINPUT_EVENT_DEVICE_ADDED, -1);
+	litest_wait_for_event_of_type(li, LIBINPUT_EVENT_DEVICE_ADDED);
 	event = libinput_get_event(li);
 	device = libinput_event_get_device(event);
 	seat = libinput_device_get_seat(device);
-	ck_assert_notnull(seat);
+	litest_assert_notnull(seat);
 
 	seat_name = libinput_seat_get_logical_name(seat);
-	ck_assert_str_eq(seat_name, "default");
+	litest_assert_str_eq(seat_name, "default");
 	libinput_event_destroy(event);
 
 	libinput_unref(li);
@@ -230,12 +229,12 @@ START_TEST(udev_change_seat)
 	struct litest_device *dev;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
-	libinput_dispatch(li);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_dispatch(li);
 
 	/* Drop any events from other devices */
 	litest_drain_events(li);
@@ -244,7 +243,7 @@ START_TEST(udev_change_seat)
 	 * logical seat. This test may fail if there is a local rule changing
 	 * that, but it'll be fine for the 99% case. */
 	dev = litest_create(LITEST_MOUSE, NULL, NULL, NULL, NULL);
-	litest_wait_for_event_of_type(li, LIBINPUT_EVENT_DEVICE_ADDED, -1);
+	litest_wait_for_event_of_type(li, LIBINPUT_EVENT_DEVICE_ADDED);
 	event = libinput_get_event(li);
 	device = libinput_event_get_device(event);
 	libinput_device_ref(device);
@@ -260,29 +259,29 @@ START_TEST(udev_change_seat)
 	/* Changing the logical seat name will remove and re-add the device */
 	rc = libinput_device_set_seat_logical_name(device,
 						   seat2_name);
-	ck_assert_int_eq(rc, 0);
+	litest_assert_int_eq(rc, 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
-	ck_assert_int_eq(libinput_event_get_type(event),
+	litest_assert_enum_eq(libinput_event_get_type(event),
 			 LIBINPUT_EVENT_DEVICE_REMOVED);
 
-	ck_assert(libinput_event_get_device(event) == device);
+	litest_assert(libinput_event_get_device(event) == device);
 	libinput_event_destroy(event);
 
 	event = libinput_get_event(li);
-	ck_assert_int_eq(libinput_event_get_type(event),
+	litest_assert_enum_eq(libinput_event_get_type(event),
 			 LIBINPUT_EVENT_DEVICE_ADDED);
-	ck_assert(libinput_event_get_device(event) != device);
+	litest_assert(libinput_event_get_device(event) != device);
 	libinput_device_unref(device);
 
 	device = libinput_event_get_device(event);
 	seat2 = libinput_device_get_seat(device);
 
-	ck_assert_str_ne(libinput_seat_get_logical_name(seat2),
+	litest_assert_str_ne(libinput_seat_get_logical_name(seat2),
 			 seat1_name);
-	ck_assert_str_eq(libinput_seat_get_logical_name(seat2),
+	litest_assert_str_eq(libinput_seat_get_logical_name(seat2),
 			 seat2_name);
 	libinput_event_destroy(event);
 
@@ -303,19 +302,19 @@ START_TEST(udev_double_suspend)
 	int fd;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
 
 	fd = libinput_get_fd(li);
-	ck_assert_int_ge(fd, 0);
+	litest_assert_int_ge(fd, 0);
 
 	/* expect at least one event */
-	ck_assert_int_ge(libinput_dispatch(li), 0);
+	litest_assert_int_ge(litest_dispatch(li), 0);
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
+	litest_assert_notnull(event);
 
 	libinput_suspend(li);
 	libinput_suspend(li);
@@ -335,19 +334,19 @@ START_TEST(udev_double_resume)
 	int fd;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
 
 	fd = libinput_get_fd(li);
-	ck_assert_int_ge(fd, 0);
+	litest_assert_int_ge(fd, 0);
 
 	/* expect at least one event */
-	ck_assert_int_ge(libinput_dispatch(li), 0);
+	litest_assert_int_ge(litest_dispatch(li), 0);
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
+	litest_assert_notnull(event);
 
 	libinput_suspend(li);
 	libinput_resume(li);
@@ -387,31 +386,31 @@ START_TEST(udev_suspend_resume)
 	int num_devices = 0;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
 
 	fd = libinput_get_fd(li);
-	ck_assert_int_ge(fd, 0);
+	litest_assert_int_ge(fd, 0);
 
 	/* Check that at least one device was discovered after creation. */
-	ck_assert_int_ge(libinput_dispatch(li), 0);
+	litest_assert_int_ge(litest_dispatch(li), 0);
 	process_events_count_devices(li, &num_devices);
-	ck_assert_int_gt(num_devices, 0);
+	litest_assert_int_gt(num_devices, 0);
 
 	/* Check that after a suspend, no devices are left. */
 	libinput_suspend(li);
-	ck_assert_int_ge(libinput_dispatch(li), 0);
+	litest_assert_int_ge(litest_dispatch(li), 0);
 	process_events_count_devices(li, &num_devices);
-	ck_assert_int_eq(num_devices, 0);
+	litest_assert_int_eq(num_devices, 0);
 
 	/* Check that after a resume, at least one device is discovered. */
 	libinput_resume(li);
-	ck_assert_int_ge(libinput_dispatch(li), 0);
+	litest_assert_int_ge(litest_dispatch(li), 0);
 	process_events_count_devices(li, &num_devices);
-	ck_assert_int_gt(num_devices, 0);
+	litest_assert_int_gt(num_devices, 0);
 
 	libinput_unref(li);
 	udev_unref(udev);
@@ -425,13 +424,13 @@ START_TEST(udev_resume_before_seat)
 	int rc;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	rc = libinput_resume(li);
-	ck_assert_int_eq(rc, 0);
+	litest_assert_int_eq(rc, 0);
 
 	libinput_unref(li);
 	udev_unref(udev);
@@ -445,14 +444,14 @@ START_TEST(udev_suspend_resume_before_seat)
 	int rc;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 
 	libinput_suspend(li);
 	rc = libinput_resume(li);
-	ck_assert_int_eq(rc, 0);
+	litest_assert_int_eq(rc, 0);
 
 	libinput_unref(li);
 	udev_unref(udev);
@@ -468,13 +467,13 @@ START_TEST(udev_device_sysname)
 	struct udev *udev;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 
 	while ((ev = libinput_get_event(li))) {
 		if (libinput_event_get_type(ev) !=
@@ -485,10 +484,10 @@ START_TEST(udev_device_sysname)
 
 		device = libinput_event_get_device(ev);
 		sysname = libinput_device_get_sysname(device);
-		ck_assert_notnull(sysname);
-		ck_assert_int_gt(strlen(sysname), 1);
-		ck_assert(strchr(sysname, '/') == NULL);
-		ck_assert(strneq(sysname, "event", 5));
+		litest_assert_notnull(sysname);
+		litest_assert_int_gt(strlen(sysname), 1U);
+		litest_assert(strchr(sysname, '/') == NULL);
+		litest_assert(strneq(sysname, "event", 5));
 		libinput_event_destroy(ev);
 	}
 
@@ -510,13 +509,13 @@ START_TEST(udev_seat_recycle)
 	void *user_data;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	while ((ev = libinput_get_event(li))) {
 		switch (libinput_event_get_type(ev)) {
 		case LIBINPUT_EVENT_DEVICE_ADDED:
@@ -524,7 +523,7 @@ START_TEST(udev_seat_recycle)
 				break;
 
 			device = libinput_event_get_device(ev);
-			ck_assert_notnull(device);
+			litest_assert_notnull(device);
 			saved_seat = libinput_device_get_seat(device);
 			libinput_seat_set_user_data(saved_seat, &data);
 			libinput_seat_ref(saved_seat);
@@ -536,7 +535,7 @@ START_TEST(udev_seat_recycle)
 		libinput_event_destroy(ev);
 	}
 
-	ck_assert_notnull(saved_seat);
+	litest_assert_notnull(saved_seat);
 
 	libinput_suspend(li);
 
@@ -544,18 +543,18 @@ START_TEST(udev_seat_recycle)
 
 	libinput_resume(li);
 
-	libinput_dispatch(li);
+	litest_dispatch(li);
 	while ((ev = libinput_get_event(li))) {
 		switch (libinput_event_get_type(ev)) {
 		case LIBINPUT_EVENT_DEVICE_ADDED:
 			device = libinput_event_get_device(ev);
-			ck_assert_notnull(device);
+			litest_assert_notnull(device);
 
 			seat = libinput_device_get_seat(device);
 			user_data = libinput_seat_get_user_data(seat);
 			if (user_data == &data) {
 				found = 1;
-				ck_assert(seat == saved_seat);
+				litest_assert(seat == saved_seat);
 			}
 			break;
 		default:
@@ -565,7 +564,7 @@ START_TEST(udev_seat_recycle)
 		libinput_event_destroy(ev);
 	}
 
-	ck_assert(found == 1);
+	litest_assert(found == 1);
 
 	libinput_unref(li);
 	udev_unref(udev);
@@ -579,15 +578,15 @@ START_TEST(udev_path_add_device)
 	struct libinput_device *device;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
 
 	litest_set_log_handler_bug(li);
 	device = libinput_path_add_device(li, "/dev/input/event0");
-	ck_assert(device == NULL);
+	litest_assert(device == NULL);
 	litest_restore_log_handler(li);
 
 	libinput_unref(li);
@@ -603,17 +602,17 @@ START_TEST(udev_path_remove_device)
 	struct libinput_event *event;
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
-	libinput_dispatch(li);
+	litest_assert_notnull(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_dispatch(li);
 
-	litest_wait_for_event_of_type(li, LIBINPUT_EVENT_DEVICE_ADDED, -1);
+	litest_wait_for_event_of_type(li, LIBINPUT_EVENT_DEVICE_ADDED);
 	event = libinput_get_event(li);
 	device = libinput_event_get_device(event);
-	ck_assert_notnull(device);
+	litest_assert_notnull(device);
 
 	/* no effect bug a bug log msg */
 	litest_set_log_handler_bug(li);
@@ -639,17 +638,17 @@ START_TEST(udev_ignore_device)
 	devname = libevdev_get_name(dev->evdev);
 
 	udev = udev_new();
-	ck_assert_notnull(udev);
+	litest_assert_notnull(udev);
 
 	li = libinput_udev_create_context(&simple_interface, NULL, udev);
-	ck_assert_notnull(li);
+	litest_assert_notnull(li);
 	litest_restore_log_handler(li);
 
-	ck_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
-	libinput_dispatch(li);
+	litest_assert_int_eq(libinput_udev_assign_seat(li, "seat0"), 0);
+	litest_dispatch(li);
 
 	event = libinput_get_event(li);
-	ck_assert_notnull(event);
+	litest_assert_notnull(event);
 	while (event) {
 		if (libinput_event_get_type(event) ==
 		    LIBINPUT_EVENT_DEVICE_ADDED) {
@@ -657,10 +656,10 @@ START_TEST(udev_ignore_device)
 
 			device = libinput_event_get_device(event);
 			name = libinput_device_get_name(device);
-			ck_assert_str_ne(devname, name);
+			litest_assert_str_ne(devname, name);
 		}
 		libinput_event_destroy(event);
-		libinput_dispatch(li);
+		litest_dispatch(li);
 		event = libinput_get_event(li);
 	}
 
