@@ -61,7 +61,7 @@ enum indent {
 	I_NONE = 0,
 	I_TOPLEVEL = 0,
 	I_LIBINPUT = 2,			/* nodes inside libinput: */
-	I_SYSTEM = 0,			/* nodes inside system:   */
+	I_SYSTEM = 2,			/* nodes inside system:   */
 	I_DEVICE = 2,			/* nodes inside devices:  */
 	I_EVDEV = 4,			/* nodes inside evdev:    */
 	I_EVDEV_DATA = 6,		/* nodes below evdev:	  */
@@ -965,7 +965,6 @@ print_tablet_tool_button_event(struct record_device *dev,
 		abort();
 	}
 
-
 	button = libinput_event_tablet_tool_get_button(t);
 	state = libinput_event_tablet_tool_get_button_state(t);
 	time = time_offset(dev->ctx, libinput_event_tablet_tool_get_time_usec(t));
@@ -1071,7 +1070,6 @@ print_tablet_pad_button_event(struct record_device *dev,
 		libinput_tablet_pad_mode_group_button_is_toggle(group, button) ? "true" : "false"
 	       );
 
-
 }
 
 static void
@@ -1291,7 +1289,10 @@ handle_libinput_events(struct record_context *ctx,
 	if (!e)
 		return false;
 
-	iprintf(d->fp, I_EVENTTYPE, "%slibinput:\n", start_frame ? "- " : "");
+	if (start_frame)
+		iprintf(d->fp, I_EVENTTYPE, "- libinput:\n");
+	else
+		iprintf(d->fp, I_EVENTTYPE, "libinput:\n");
 	do {
 		struct libinput_device *device = libinput_event_get_device(e);
 
@@ -1485,12 +1486,37 @@ static void
 print_description(FILE *fp, struct libevdev *dev)
 {
 	const struct input_absinfo *x, *y;
+	int bustype;
+	const char *busname;
+
+	bustype = libevdev_get_id_bustype(dev);
+	switch (bustype) {
+	case BUS_USB:
+		busname = " (usb) ";
+		break;
+	case BUS_BLUETOOTH:
+		busname = " (bluetooth) ";
+		break;
+	case BUS_I2C:
+		busname = " (i2c) ";
+		break;
+	case BUS_SPI:
+		busname = " (spi) ";
+		break;
+	case BUS_RMI:
+		busname = " (rmi) ";
+		break;
+	default:
+		busname = " ";
+		break;
+	}
 
 	iprintf(fp, I_EVDEV, "# Name: %s\n", libevdev_get_name(dev));
 	iprintf(fp,
 		I_EVDEV,
-		"# ID: bus %#02x vendor %#02x product %#02x version %#02x\n",
-		libevdev_get_id_bustype(dev),
+		"# ID: bus 0x%04x%svendor 0x%04x product 0x%04x version 0x%04x\n",
+		bustype,
+		busname,
 		libevdev_get_id_vendor(dev),
 		libevdev_get_id_product(dev),
 		libevdev_get_id_version(dev));
@@ -1731,6 +1757,16 @@ print_udev_properties(struct record_device *dev)
 		entry = udev_list_entry_get_next(entry);
 	}
 
+	for (struct udev_device *parent = udev_device;
+	     parent;
+	     parent = udev_device_get_parent(parent)) {
+		const char *driver = udev_device_get_property_value(parent, "DRIVER");
+		if (driver) {
+			iprintf(dev->fp, I_UDEV_DATA, "- DRIVER=%s\n", driver);
+			break;
+		}
+	}
+
 out:
 	udev_device_unref(udev_device);
 	udev_unref(udev);
@@ -1781,9 +1817,13 @@ print_device_quirks(struct record_device *dev)
 				       QLOG_CUSTOM_LOG_PRIORITIES);
 	if (!quirks) {
 		fprintf(stderr,
-			"Failed to initialize the device quirks. "
-			"Please see the above errors "
-			"and/or re-run with --verbose for more details\n");
+			"Failed to load the device quirks from %s%s%s. "
+			"This will negatively affect device behavior. "
+			"See %s/device-quirks.html for details.\n",
+			data_path,
+			override_file ? " and " : "",
+			override_file ? override_file : "",
+			HTTP_DOC_LINK);
 		return;
 	}
 
@@ -1820,7 +1860,6 @@ print_libinput_description(struct record_device *dev)
 		{LIBINPUT_DEVICE_CAP_GESTURE, "gesture"},
 		{LIBINPUT_DEVICE_CAP_SWITCH, "switch"},
 	};
-	struct cap *cap;
 	const char *sep = "";
 
 	if (!device)
@@ -2438,7 +2477,7 @@ static void close_restricted(int fd, void *user_data)
 	close(fd);
 }
 
-const struct libinput_interface interface = {
+static const struct libinput_interface interface = {
 	.open_restricted = open_restricted,
 	.close_restricted = close_restricted,
 };
@@ -2573,7 +2612,7 @@ is_char_dev(const char *path)
 
 enum fposition {
 	ERROR,
-	NOFILE,
+	NO_FILE,
 	FIRST,
 	LAST,
 };
@@ -2629,7 +2668,7 @@ find_output_file(int argc, char *argv[], const char **output_file)
 		return ERROR;
 	}
 #undef _m
-	return NOFILE;
+	return NO_FILE;
 }
 
 enum options {
